@@ -1,7 +1,4 @@
-# Authors: Marijn van Vliet <w.m.vanvliet@gmail.com>
-#          Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Teon Brooks <teon.brooks@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -302,7 +299,7 @@ def test_set_eeg_reference_ch_type(ch_type, msg, projection):
     # gh-8739
     raw2 = RawArray(data, create_info(5, 1000.0, ["mag"] * 4 + ["misc"]))
     with pytest.raises(
-        ValueError, match="No EEG, ECoG, sEEG or DBS channels " "found to rereference."
+        ValueError, match="No EEG, ECoG, sEEG or DBS channels found to rereference."
     ):
         set_eeg_reference(raw2, ch_type="auto", projection=projection)
 
@@ -736,7 +733,7 @@ def test_add_reorder(n_ref):
     # gh-8300
     raw = read_raw_fif(raw_fname).crop(0, 0.1).del_proj().pick("eeg")
     assert len(raw.ch_names) == 60
-    chs = ["EEG %03d" % (60 + ii) for ii in range(1, n_ref)] + ["EEG 000"]
+    chs = [f"EEG {60 + ii:03}" for ii in range(1, n_ref)] + ["EEG 000"]
     with pytest.raises(RuntimeError, match="preload"):
         with _record_warnings():  # ignore multiple warning
             add_reference_channels(raw, chs, copy=False)
@@ -752,7 +749,7 @@ def test_add_reorder(n_ref):
     assert_array_equal(data[-1], 0.0)
     assert raw.ch_names[-n_ref:] == chs
     raw.reorder_channels(raw.ch_names[-1:] + raw.ch_names[:-1])
-    assert raw.ch_names == ["EEG %03d" % ii for ii in range(60 + n_ref)]
+    assert raw.ch_names == [f"EEG {ii:03}" for ii in range(60 + n_ref)]
     data_new = raw.get_data()
     data_new = np.concatenate([data_new[1:], data_new[:1]])
     assert_allclose(data, data_new)
