@@ -1,12 +1,4 @@
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Matti Hämäläinen <msh@nmr.mgh.harvard.edu>
-#          Martin Luessi <mluessi@nmr.mgh.harvard.edu>
-#          Denis Engemann <denis.engemann@gmail.com>
-#          Teon Brooks <teon.brooks@gmail.com>
-#          Marijn van Vliet <w.m.vanvliet@gmail.com>
-#          Mainak Jas <mainak.jas@telecom-paristech.fr>
-#          Stefan Appelhoff <stefan.appelhoff@mailbox.org>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -254,7 +246,7 @@ def _read_segments_file(
 
 def read_str(fid, count=1):
     """Read string from a binary file in a python version compatible way."""
-    dtype = np.dtype(">S%i" % count)
+    dtype = np.dtype(f">S{count}")
     string = fid.read(dtype.itemsize)
     data = np.frombuffer(string, dtype=dtype)[0]
     bytestr = b"".join([data[0 : data.index(b"\x00") if b"\x00" in data else count]])
@@ -301,31 +293,6 @@ def _create_chs(ch_names, cals, ch_coil, ch_kind, eog, ecg, emg, misc):
     return chs
 
 
-def _synthesize_stim_channel(events, n_samples):
-    """Synthesize a stim channel from events read from an event file.
-
-    Parameters
-    ----------
-    events : array, shape (n_events, 3)
-        Each row representing an event.
-    n_samples : int
-        The number of samples.
-
-    Returns
-    -------
-    stim_channel : array, shape (n_samples,)
-        An array containing the whole recording's event marking.
-    """
-    # select events overlapping buffer
-    events = events.copy()
-    events[events[:, 1] < 1, 1] = 1
-    # create output buffer
-    stim_channel = np.zeros(n_samples, int)
-    for onset, duration, trigger in events:
-        stim_channel[onset : onset + duration] = trigger
-    return stim_channel
-
-
 def _construct_bids_filename(base, ext, part_idx, validate=True):
     """Construct a BIDS compatible filename for split files."""
     # insert index in filename
