@@ -1,6 +1,4 @@
-# Authors: Adam Li <adam2392@gmail.com>
-#          Daniel McCloy <dan@mccloy.info>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -358,9 +356,7 @@ MNE_DATASETS["hf_sef_evoked"] = dict(
 MNE_DATASETS["fake"] = dict(
     archive_name="foo.tgz",
     hash="md5:3194e9f7b46039bb050a74f3e1ae9908",
-    url=(
-        "https://github.com/mne-tools/mne-testing-data/raw/master/" "datasets/foo.tgz"
-    ),
+    url="https://github.com/mne-tools/mne-testing-data/raw/master/datasets/foo.tgz",
     folder_name="foo",
     config_key="MNE_DATASETS_FAKE_PATH",
 )
