@@ -1,11 +1,4 @@
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Martin Luessi <mluessi@nmr.mgh.harvard.edu>
-#          Eric Larson <larson.eric.d@gmail.com>
-#          Denis Egnemann <denis.engemann@gmail.com>
-#          Stefan Appelhoff <stefan.appelhoff@mailbox.org>
-#          Adam Li <adam2392@gmail.com>
-#          Daniel McCloy <dan@mccloy.info>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -20,6 +13,7 @@ import time
 import zipfile
 from collections import OrderedDict
 from pathlib import Path
+from typing import cast
 
 import numpy as np
 
@@ -119,21 +113,21 @@ def _get_path(path, key, name):
         return path
     # 4. ~/mne_data (but use a fake home during testing so we don't
     #    unnecessarily create ~/mne_data)
-    logger.info("Using default location ~/mne_data for %s..." % name)
-    path = op.join(os.getenv("_MNE_FAKE_HOME_DIR", op.expanduser("~")), "mne_data")
-    if not op.exists(path):
-        logger.info("Creating ~/mne_data")
+    logger.info(f"Using default location ~/mne_data for {name}...")
+    path = Path(os.getenv("_MNE_FAKE_HOME_DIR", "~")).expanduser() / "mne_data"
+    if not path.is_dir():
+        logger.info(f"Creating {path}")
         try:
-            os.mkdir(path)
+            path.mkdir()
         except OSError:
             raise OSError(
                 "User does not have write permissions "
-                "at '%s', try giving the path as an "
+                f"at '{path}', try giving the path as an "
                 "argument to data_path() where user has "
                 "write permissions, for ex:data_path"
-                "('/home/xyz/me2/')" % (path)
+                "('/home/xyz/me2/')"
             )
-    return Path(path).expanduser()
+    return path
 
 
 def _do_path_update(path, update_path, key, name):
@@ -210,7 +204,7 @@ def _check_in_testing_and_raise(name, download):
 
 def _download_mne_dataset(
     name, processor, path, force_update, update_path, download, accept=False
-):
+) -> Path:
     """Aux function for downloading internal MNE datasets."""
     import pooch
 
@@ -243,14 +237,17 @@ def _download_mne_dataset(
             this_dataset["dataset_name"] = name
             dataset_params.append(this_dataset)
 
-    return fetch_dataset(
-        dataset_params=dataset_params,
-        processor=processor_,
-        path=path,
-        force_update=force_update,
-        update_path=update_path,
-        download=download,
-        accept=accept,
+    return cast(
+        Path,
+        fetch_dataset(
+            dataset_params=dataset_params,
+            processor=processor_,
+            path=path,
+            force_update=force_update,
+            update_path=update_path,
+            download=download,
+            accept=accept,
+        ),
     )
 
 
@@ -464,9 +461,9 @@ def fetch_hcp_mmp_parcellation(
         if accept or "--accept-hcpmmp-license" in sys.argv:
             answer = "y"
         else:
-            answer = _safe_input("%s\nAgree (y/[n])? " % _hcp_mmp_license_text)
+            answer = _safe_input(f"{_hcp_mmp_license_text}\nAgree (y/[n])? ")
         if answer.lower() != "y":
-            raise RuntimeError("You must agree to the license to use this " "dataset")
+            raise RuntimeError("You must agree to the license to use this dataset")
     downloader = pooch.HTTPDownloader(**_downloader_params())
     for hemi, fpath in zip(("lh", "rh"), fnames):
         if not op.isfile(fpath):
@@ -481,7 +478,7 @@ def fetch_hcp_mmp_parcellation(
 
     if combine:
         fnames = [
-            op.join(destination, "%s.HCPMMP1_combined.annot" % hemi)
+            op.join(destination, f"{hemi}.HCPMMP1_combined.annot")
             for hemi in ("lh", "rh")
         ]
         if all(op.isfile(fname) for fname in fnames):
@@ -764,27 +761,27 @@ def _manifest_check_download(manifest_path, destination, url, hash_):
 
     with open(manifest_path) as fid:
         names = [name.strip() for name in fid.readlines()]
-    manifest_path = op.basename(manifest_path)
     need = list()
     for name in names:
-        if not op.isfile(op.join(destination, name)):
+        if not (destination / name).is_file():
             need.append(name)
     logger.info(
         "%d file%s missing from %s in %s"
-        % (len(need), _pl(need), manifest_path, destination)
+        % (len(need), _pl(need), manifest_path.name, destination)
     )
     if len(need) > 0:
         downloader = pooch.HTTPDownloader(**_downloader_params())
         with tempfile.TemporaryDirectory() as path:
             logger.info("Downloading missing files remotely")
 
-            fname_path = op.join(path, "temp.zip")
+            path = Path(path)
+            fname_path = path / "temp.zip"
             pooch.retrieve(
                 url=url,
                 known_hash=f"md5:{hash_}",
                 path=path,
                 downloader=downloader,
-                fname=op.basename(fname_path),
+                fname=fname_path.name,
             )
 
             logger.info(f"Extracting missing file{_pl(need)}")
@@ -813,7 +810,7 @@ def _log_time_size(t0, sz):
 
 
 def _downloader_params(*, auth=None, token=None):
-    params = dict()
+    params = dict(timeout=15)
     params["progressbar"] = (
         logger.level <= logging.INFO and get_config("MNE_TQDM", "tqdm.auto") != "off"
     )
