@@ -1,7 +1,7 @@
-# Author: Jean-Remi King <jeanremi.king@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
+
 import logging
 
 import numpy as np
@@ -67,7 +67,7 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
         repr_str = "<" + super().__repr__()
         if hasattr(self, "estimators_"):
             repr_str = repr_str[:-1]
-            repr_str += ", fitted with %i estimators" % len(self.estimators_)
+            repr_str += f", fitted with {len(self.estimators_)} estimators"
         return repr_str + ">"
 
     def fit(self, X, y, **fit_params):
@@ -144,7 +144,7 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
         X = self._check_Xy(X)
         method = _check_method(self.base_estimator, method)
         if X.shape[-1] != len(self.estimators_):
-            raise ValueError("The number of estimators does not match " "X.shape[-1]")
+            raise ValueError("The number of estimators does not match X.shape[-1]")
         # For predictions/transforms the parallelization is across the data and
         # not across the estimators to avoid memory load.
         parallel, p_func, n_jobs = parallel_func(
@@ -304,7 +304,7 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
 
         X = self._check_Xy(X, y)
         if X.shape[-1] != len(self.estimators_):
-            raise ValueError("The number of estimators does not match " "X.shape[-1]")
+            raise ValueError("The number of estimators does not match X.shape[-1]")
 
         scoring = check_scoring(self.base_estimator, self.scoring)
         y = _fix_auc(scoring, y)
@@ -450,7 +450,7 @@ def _check_method(estimator, method):
     if method == "transform" and not hasattr(estimator, "transform"):
         method = "predict"
     if not hasattr(estimator, method):
-        ValueError("base_estimator does not have `%s` method." % method)
+        ValueError(f"base_estimator does not have `{method}` method.")
     return method
 
 
@@ -475,7 +475,7 @@ class GeneralizingEstimator(SlidingEstimator):
         repr_str = super().__repr__()
         if hasattr(self, "estimators_"):
             repr_str = repr_str[:-1]
-            repr_str += ", fitted with %i estimators>" % len(self.estimators_)
+            repr_str += f", fitted with {len(self.estimators_)} estimators>"
         return repr_str
 
     def _transform(self, X, method):
@@ -732,7 +732,7 @@ def _fix_auc(scoring, y):
         ):
             if np.ndim(y) != 1 or len(set(y)) != 2:
                 raise ValueError(
-                    "roc_auc scoring can only be computed for " "two-class problems."
+                    "roc_auc scoring can only be computed for two-class problems."
                 )
             y = LabelEncoder().fit_transform(y)
     return y
