@@ -1,6 +1,4 @@
-# Author: Denis A. Engemann <denis.engemann@gmail.com>
-#         Victoria Peterson <victoriapeterson09@gmail.com>
-#         Thomas S. Binns <t.s.binns@outlook.com>
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -177,8 +175,8 @@ class SSD(BaseEstimator, TransformerMixin):
             The input data from which to estimate the SSD. Either 2D array
             obtained from continuous data or 3D array obtained from epoched
             data.
-        y : None | array, shape (n_samples,)
-            Used for scikit-learn compatibility.
+        y : None
+            Ignored; exists for compatibility with scikit-learn pipelines.
 
         Returns
         -------
