@@ -1,7 +1,4 @@
-# Authors: Mainak Jas <mainak@neuro.hut.fi>
-#          Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Romain Trachel <trachelr@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -38,7 +35,7 @@ class _ConstantScaler:
         std = np.ones(sum(len(p[1]) for p in picks_by_type))
         if X.shape[1] != len(std):
             raise ValueError(
-                "info had %d data channels but X has %d channels" % (len(std), len(X))
+                f"info had {len(std)} data channels but X has {len(X)} channels"
             )
         if self._do_scaling:  # this is silly, but necessary for completeness
             for kind, picks in picks_by_type:
@@ -60,7 +57,7 @@ class _ConstantScaler:
 def _sklearn_reshape_apply(func, return_result, X, *args, **kwargs):
     """Reshape epochs and apply function."""
     if not isinstance(X, np.ndarray):
-        raise ValueError("data should be an np.ndarray, got %s." % type(X))
+        raise ValueError(f"data should be an np.ndarray, got {type(X)}.")
     orig_shape = X.shape
     X = np.reshape(X.transpose(0, 2, 1), (-1, orig_shape[1]))
     X = func(X, *args, **kwargs)
@@ -115,14 +112,14 @@ class Scaler(TransformerMixin, BaseEstimator):
 
         if not (scalings is None or isinstance(scalings, (dict, str))):
             raise ValueError(
-                "scalings type should be dict, str, or None, " "got %s" % type(scalings)
+                f"scalings type should be dict, str, or None, got {type(scalings)}"
             )
         if isinstance(scalings, str):
             _check_option("scalings", scalings, ["mean", "median"])
         if scalings is None or isinstance(scalings, dict):
             if info is None:
                 raise ValueError(
-                    'Need to specify "info" if scalings is' "%s" % type(scalings)
+                    f'Need to specify "info" if scalings is {type(scalings)}'
                 )
             self._scaler = _ConstantScaler(info, scalings, self.with_std)
         elif scalings == "mean":
@@ -217,7 +214,7 @@ class Scaler(TransformerMixin, BaseEstimator):
 
         Parameters
         ----------
-        epochs_data : array, shape (n_epochs, n_channels, n_times)
+        epochs_data : array, shape ([n_epochs, ]n_channels, n_times)
             The data.
 
         Returns
@@ -230,8 +227,16 @@ class Scaler(TransformerMixin, BaseEstimator):
         This function makes a copy of the data before the operations and the
         memory usage may be large with big data.
         """
+        squeeze = False
+        # Can happen with CSP
+        if epochs_data.ndim == 2:
+            squeeze = True
+            epochs_data = epochs_data[..., np.newaxis]
         assert epochs_data.ndim == 3, epochs_data.shape
-        return _sklearn_reshape_apply(self._scaler.inverse_transform, True, epochs_data)
+        out = _sklearn_reshape_apply(self._scaler.inverse_transform, True, epochs_data)
+        if squeeze:
+            out = out[..., 0]
+        return out
 
 
 class Vectorizer(TransformerMixin):
@@ -291,7 +296,7 @@ class Vectorizer(TransformerMixin):
         """
         X = np.asarray(X)
         if X.shape[1:] != self.features_shape_:
-            raise ValueError("Shape of X used in fit and transform must be " "same")
+            raise ValueError("Shape of X used in fit and transform must be same")
         return X.reshape(len(X), -1)
 
     def fit_transform(self, X, y=None):
@@ -331,7 +336,7 @@ class Vectorizer(TransformerMixin):
         X = np.asarray(X)
         if X.ndim not in (2, 3):
             raise ValueError(
-                "X should be of 2 or 3 dimensions but has shape " f"{X.shape}"
+                f"X should be of 2 or 3 dimensions but has shape {X.shape}"
             )
         return X.reshape(X.shape[:-1] + self.features_shape_)
 
@@ -409,7 +414,7 @@ class PSDEstimator(TransformerMixin):
         """
         if not isinstance(epochs_data, np.ndarray):
             raise ValueError(
-                "epochs_data should be of type ndarray (got %s)." % type(epochs_data)
+                f"epochs_data should be of type ndarray (got {type(epochs_data)})."
             )
 
         return self
@@ -429,7 +434,7 @@ class PSDEstimator(TransformerMixin):
         """
         if not isinstance(epochs_data, np.ndarray):
             raise ValueError(
-                "epochs_data should be of type ndarray (got %s)." % type(epochs_data)
+                f"epochs_data should be of type ndarray (got {type(epochs_data)})."
             )
         psd, _ = psd_array_multitaper(
             epochs_data,
@@ -540,7 +545,7 @@ class FilterEstimator(TransformerMixin):
         """
         if not isinstance(epochs_data, np.ndarray):
             raise ValueError(
-                "epochs_data should be of type ndarray (got %s)." % type(epochs_data)
+                f"epochs_data should be of type ndarray (got {type(epochs_data)})."
             )
 
         if self.picks is None:
@@ -590,7 +595,7 @@ class FilterEstimator(TransformerMixin):
         """
         if not isinstance(epochs_data, np.ndarray):
             raise ValueError(
-                "epochs_data should be of type ndarray (got %s)." % type(epochs_data)
+                f"epochs_data should be of type ndarray (got {type(epochs_data)})."
             )
         epochs_data = np.atleast_3d(epochs_data)
         return filter_data(
@@ -629,12 +634,12 @@ class UnsupervisedSpatialFilter(TransformerMixin, BaseEstimator):
             if not hasattr(estimator, attr):
                 raise ValueError(
                     "estimator must be a scikit-learn "
-                    "transformer, missing %s method" % attr
+                    f"transformer, missing {attr} method"
                 )
 
         if not isinstance(average, bool):
             raise ValueError(
-                "average parameter must be of bool type, got " "%s instead" % type(bool)
+                f"average parameter must be of bool type, got {type(bool)} instead"
             )
 
         self.estimator = estimator
@@ -851,7 +856,7 @@ class TemporalFilter(TransformerMixin):
 
         if not isinstance(self.n_jobs, int) and self.n_jobs == "cuda":
             raise ValueError(
-                'n_jobs must be int or "cuda", got %s instead.' % type(self.n_jobs)
+                f'n_jobs must be int or "cuda", got {type(self.n_jobs)} instead.'
             )
 
     def fit(self, X, y=None):
@@ -891,7 +896,7 @@ class TemporalFilter(TransformerMixin):
         if X.ndim > 3:
             raise ValueError(
                 "Array must be of at max 3 dimensions instead "
-                "got %s dimensional matrix" % (X.ndim)
+                f"got {X.ndim} dimensional matrix"
             )
 
         shape = X.shape
