@@ -6,10 +6,8 @@ at which the fix is no longer needed.
 # originally copied from scikit-learn
 
 """
-# Authors: Emmanuelle Gouillart <emmanuelle.gouillart@normalesup.org>
-#          Gael Varoquaux <gael.varoquaux@normalesup.org>
-#          Fabian Pedregosa <fpedregosa@acm.org>
-#          Lars Buitinck <L.J.Buitinck@uva.nl>
+
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -21,7 +19,6 @@ import inspect
 import operator as operator_module
 import os
 import warnings
-from contextlib import contextmanager
 from io import StringIO
 from math import log
 from pprint import pprint
@@ -102,10 +99,17 @@ def _safe_svd(A, **kwargs):
         return linalg.svd(A, lapack_driver="gesvd", **kwargs)
 
 
-def _csc_matrix_cast(x):
-    from scipy.sparse import csc_matrix
+def _csc_array_cast(x):
+    from scipy.sparse import csc_array
 
-    return csc_matrix(x)
+    return csc_array(x)
+
+
+# Can be replaced with sparse.eye_array once we depend on SciPy >= 1.12
+def _eye_array(n, *, format="csr"):  # noqa: A002
+    from scipy import sparse
+
+    return sparse.dia_array((np.ones(n), 0), shape=(n, n)).asformat(format)
 
 
 ###############################################################################
@@ -384,7 +388,7 @@ def empirical_covariance(X, assume_centered=False):
 
     if X.shape[0] == 1:
         warnings.warn(
-            "Only one sample available. " "You may want to reshape your data array"
+            "Only one sample available. You may want to reshape your data array"
         )
 
     if assume_centered:
@@ -649,7 +653,7 @@ def _assess_dimension_(spectrum, rank, n_samples, n_features):
     from scipy.special import gammaln
 
     if rank > len(spectrum):
-        raise ValueError("The tested rank cannot exceed the rank of the" " dataset")
+        raise ValueError("The tested rank cannot exceed the rank of the dataset")
 
     pu = -rank * log(2.0)
     for i in range(rank):
@@ -814,7 +818,6 @@ else:
 
 # workaround: plt.close() doesn't spawn close_event on Agg backend
 # https://github.com/matplotlib/matplotlib/issues/18609
-# scheduled to be fixed by MPL 3.6
 def _close_event(fig):
     """Force calling of the MPL figure close event."""
     from matplotlib import backend_bases
@@ -832,63 +835,8 @@ def _close_event(fig):
         pass  # pragma: no cover
 
 
-def _is_last_row(ax):
-    try:
-        return ax.get_subplotspec().is_last_row()  # 3.4+
-    except AttributeError:
-        return ax.is_last_row()
-    return ax.get_subplotspec().is_last_row()
-
-
-def _sharex(ax1, ax2):
-    if hasattr(ax1.axes, "sharex"):
-        ax1.axes.sharex(ax2)
-    else:
-        ax1.get_shared_x_axes().join(ax1, ax2)
-
-
 ###############################################################################
-# SciPy deprecation of pinv + pinvh rcond (never worked properly anyway) in 1.7
-
-
-def pinvh(a, rtol=None):
-    """Compute a pseudo-inverse of a Hermitian matrix."""
-    s, u = np.linalg.eigh(a)
-    del a
-    if rtol is None:
-        rtol = s.size * np.finfo(s.dtype).eps
-    maxS = np.max(np.abs(s))
-    above_cutoff = abs(s) > maxS * rtol
-    psigma_diag = 1.0 / s[above_cutoff]
-    u = u[:, above_cutoff]
-    return (u * psigma_diag) @ u.conj().T
-
-
-def pinv(a, rtol=None):
-    """Compute a pseudo-inverse of a matrix."""
-    u, s, vh = _safe_svd(a, full_matrices=False)
-    del a
-    maxS = np.max(s)
-    if rtol is None:
-        rtol = max(vh.shape + u.shape) * np.finfo(u.dtype).eps
-    rank = np.sum(s > maxS * rtol)
-    u = u[:, :rank]
-    u /= s[:rank]
-    return (u @ vh[:rank]).conj().T
-
-
-###############################################################################
-# h5py uses np.product which is deprecated in NumPy 1.25
-
-
-@contextmanager
-def _numpy_h5py_dep():
-    # h5io uses np.product
-    with warnings.catch_warnings(record=True):
-        warnings.filterwarnings(
-            "ignore", "`product` is deprecated.*", DeprecationWarning
-        )
-        yield
+# SciPy 1.14+ minimum_phase half=True option
 
 
 def minimum_phase(h, method="homomorphic", n_fft=None, *, half=True):
@@ -917,7 +865,7 @@ def minimum_phase(h, method="homomorphic", n_fft=None, *, half=True):
         n_fft = 2 ** int(np.ceil(np.log2(2 * (len(h) - 1) / 0.01)))
     n_fft = int(n_fft)
     if n_fft < len(h):
-        raise ValueError("n_fft must be at least len(h)==%s" % len(h))
+        raise ValueError(f"n_fft must be at least len(h)=={len(h)}")
 
     # zero-pad; calculate the DFT
     h_temp = np.abs(fft(h, n_fft))
