@@ -1,6 +1,4 @@
-# Authors: Matti Hämäläinen <msh@nmr.mgh.harvard.edu>
-#          Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Eric Larson <larson.eric.d@gmail.com>
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -351,7 +349,7 @@ def _make_surface_mapping(
         raise KeyError('surf must have both "rr" and "nn"')
     if "coord_frame" not in surf:
         raise KeyError(
-            "The surface coordinate frame must be specified " 'in surf["coord_frame"]'
+            'The surface coordinate frame must be specified in surf["coord_frame"]'
         )
     _check_option("mode", mode, ["accurate", "fast"])
 
