@@ -1,7 +1,4 @@
-# Authors: Matti Hämäläinen <msh@nmr.mgh.harvard.edu>
-#          Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Martin Luessi <mluessi@nmr.mgh.harvard.edu>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -225,17 +222,11 @@ class Forward(dict):
 
     @repr_html
     def _repr_html_(self):
-        (
-            good_chs,
-            bad_chs,
-            _,
-            _,
-        ) = self["info"]._get_chs_for_repr()
         src_descr, src_ori = self._get_src_type_and_ori_for_repr()
+
         t = _get_html_template("repr", "forward.html.jinja")
         html = t.render(
-            good_channels=good_chs,
-            bad_channels=bad_chs,
+            info=self["info"],
             source_space_descr=src_descr,
             source_orientation=src_ori,
         )
@@ -298,7 +289,7 @@ def _block_diag(A, n):
 
     Returns
     -------
-    bd : scipy.sparse.spmatrix
+    bd : scipy.sparse.csc_array
         The block diagonal matrix
     """
     if sparse.issparse(A):  # then make block sparse
@@ -317,7 +308,7 @@ def _block_diag(A, n):
     jj = jj * np.ones(ma, dtype=np.int64)[:, None]
     jj = jj.T.ravel()  # column indices foreach sparse bd
 
-    bd = sparse.coo_matrix((A.T.ravel(), np.c_[ii, jj].T)).tocsc()
+    bd = sparse.coo_array((A.T.ravel(), np.c_[ii, jj].T)).tocsc()
 
     return bd
 
@@ -375,7 +366,7 @@ def _read_one(fid, node):
             one["sol_grad"]["data"].shape[1] != 3 * one["nsource"]
             and one["sol_grad"]["data"].shape[1] != 3 * 3 * one["nsource"]
         ):
-            raise ValueError("Forward solution gradient matrix has " "wrong dimensions")
+            raise ValueError("Forward solution gradient matrix has wrong dimensions")
 
     return one
 
@@ -572,7 +563,7 @@ def read_forward_solution(fname, include=(), exclude=(), *, ordered=True, verbos
     )
     fname = _check_fname(fname=fname, must_exist=True, overwrite="read")
     #   Open the file, create directory
-    logger.info("Reading forward solution from %s..." % fname)
+    logger.info(f"Reading forward solution from {fname}...")
     if fname.suffix == ".h5":
         return _read_forward_hdf5(fname)
     f, tree, _ = fiff_open(fname)
@@ -580,12 +571,12 @@ def read_forward_solution(fname, include=(), exclude=(), *, ordered=True, verbos
         #   Find all forward solutions
         fwds = dir_tree_find(tree, FIFF.FIFFB_MNE_FORWARD_SOLUTION)
         if len(fwds) == 0:
-            raise ValueError("No forward solutions in %s" % fname)
+            raise ValueError(f"No forward solutions in {fname}")
 
         #   Parent MRI data
         parent_mri = dir_tree_find(tree, FIFF.FIFFB_MNE_PARENT_MRI_FILE)
         if len(parent_mri) == 0:
-            raise ValueError("No parent MRI information in %s" % fname)
+            raise ValueError(f"No parent MRI information in {fname}")
         parent_mri = parent_mri[0]
 
         src = _read_source_spaces_from_tree(fid, tree, patch_stats=False)
@@ -600,9 +591,7 @@ def read_forward_solution(fname, include=(), exclude=(), *, ordered=True, verbos
         for k in range(len(fwds)):
             tag = find_tag(fid, fwds[k], FIFF.FIFF_MNE_INCLUDED_METHODS)
             if tag is None:
-                raise ValueError(
-                    "Methods not listed for one of the forward " "solutions"
-                )
+                raise ValueError("Methods not listed for one of the forward solutions")
 
             if tag.data == FIFF.FIFFV_MNE_MEG:
                 megnode = fwds[k]
@@ -656,7 +645,7 @@ def read_forward_solution(fname, include=(), exclude=(), *, ordered=True, verbos
                 or mri_head_t["to"] != FIFF.FIFFV_COORD_HEAD
             ):
                 fid.close()
-                raise ValueError("MRI/head coordinate transformation not " "found")
+                raise ValueError("MRI/head coordinate transformation not found")
         fwd["mri_head_t"] = mri_head_t
 
         #
@@ -696,7 +685,7 @@ def read_forward_solution(fname, include=(), exclude=(), *, ordered=True, verbos
         try:
             s = transform_surface_to(s, fwd["coord_frame"], mri_head_t)
         except Exception as inst:
-            raise ValueError("Could not transform source space (%s)" % inst)
+            raise ValueError(f"Could not transform source space ({inst})")
 
         nuse += s["nuse"]
 
@@ -705,7 +694,7 @@ def read_forward_solution(fname, include=(), exclude=(), *, ordered=True, verbos
         raise ValueError("Source spaces do not match the forward solution.")
 
     logger.info(
-        "    Source spaces transformed to the forward solution " "coordinate frame"
+        "    Source spaces transformed to the forward solution coordinate frame"
     )
     fwd["src"] = src
 
@@ -805,11 +794,11 @@ def convert_forward_solution(
             fix_rot = _block_diag(fwd["source_nn"].T, 1)
             # newer versions of numpy require explicit casting here, so *= no
             # longer works
-            fwd["sol"]["data"] = (fwd["_orig_sol"] * fix_rot).astype("float32")
+            fwd["sol"]["data"] = (fwd["_orig_sol"] @ fix_rot).astype("float32")
             fwd["sol"]["ncol"] = fwd["nsource"]
             if fwd["sol_grad"] is not None:
                 x = sparse.block_diag([fix_rot] * 3)
-                fwd["sol_grad"]["data"] = fwd["_orig_sol_grad"] * x  # dot prod
+                fwd["sol_grad"]["data"] = fwd["_orig_sol_grad"] @ x
                 fwd["sol_grad"]["ncol"] = 3 * fwd["nsource"]
         fwd["source_ori"] = FIFF.FIFFV_MNE_FIXED_ORI
         fwd["surf_ori"] = True
@@ -836,21 +825,21 @@ def convert_forward_solution(
             fix_rot = _block_diag(fwd["source_nn"].T, 1)
             # newer versions of numpy require explicit casting here, so *= no
             # longer works
-            fwd["sol"]["data"] = (fwd["_orig_sol"] * fix_rot).astype("float32")
+            fwd["sol"]["data"] = (fwd["_orig_sol"] @ fix_rot).astype("float32")
             fwd["sol"]["ncol"] = fwd["nsource"]
             if fwd["sol_grad"] is not None:
                 x = sparse.block_diag([fix_rot] * 3)
-                fwd["sol_grad"]["data"] = fwd["_orig_sol_grad"] * x  # dot prod
+                fwd["sol_grad"]["data"] = fwd["_orig_sol_grad"] @ x
                 fwd["sol_grad"]["ncol"] = 3 * fwd["nsource"]
             fwd["source_ori"] = FIFF.FIFFV_MNE_FIXED_ORI
             fwd["surf_ori"] = True
         else:
             surf_rot = _block_diag(fwd["source_nn"].T, 3)
-            fwd["sol"]["data"] = fwd["_orig_sol"] * surf_rot
+            fwd["sol"]["data"] = fwd["_orig_sol"] @ surf_rot
             fwd["sol"]["ncol"] = 3 * fwd["nsource"]
             if fwd["sol_grad"] is not None:
                 x = sparse.block_diag([surf_rot] * 3)
-                fwd["sol_grad"]["data"] = fwd["_orig_sol_grad"] * x  # dot prod
+                fwd["sol_grad"]["data"] = fwd["_orig_sol_grad"] @ x
                 fwd["sol_grad"]["ncol"] = 9 * fwd["nsource"]
             fwd["source_ori"] = FIFF.FIFFV_MNE_FREE_ORI
             fwd["surf_ori"] = True
@@ -966,7 +955,7 @@ def _write_forward_solution(fid, fwd):
             # usually MRI
             s = transform_surface_to(s, fwd["mri_head_t"]["from"], fwd["mri_head_t"])
         except Exception as inst:
-            raise ValueError("Could not transform source space (%s)" % inst)
+            raise ValueError(f"Could not transform source space ({inst})")
         src.append(s)
 
     #
@@ -1466,7 +1455,7 @@ def compute_depth_prior(
         if not is_fixed_ori and combine_xyz is False:
             patch_areas = np.repeat(patch_areas, 3)
         d /= patch_areas**2
-        logger.info("    Patch areas taken into account in the depth " "weighting")
+        logger.info("    Patch areas taken into account in the depth weighting")
 
     w = 1.0 / d
     if limit is not None:
@@ -1532,7 +1521,7 @@ def _stc_src_sel(
     n_stc = sum(len(v) for v in vertices)
     n_joint = len(src_sel)
     if n_joint != n_stc:
-        msg = "Only %i of %i SourceEstimate %s found in " "source space%s" % (
+        msg = "Only %i of %i SourceEstimate %s found in source space%s" % (
             n_joint,
             n_stc,
             "vertex" if n_stc == 1 else "vertices",
@@ -1671,8 +1660,8 @@ def apply_forward(
     for ch_name in fwd["sol"]["row_names"]:
         if ch_name not in info["ch_names"]:
             raise ValueError(
-                "Channel %s of forward operator not present in "
-                "evoked_template." % ch_name
+                f"Channel {ch_name} of forward operator not present in "
+                "evoked_template."
             )
 
     # project the source estimate to the sensor space
@@ -1747,7 +1736,7 @@ def apply_forward_raw(
     for ch_name in fwd["sol"]["row_names"]:
         if ch_name not in info["ch_names"]:
             raise ValueError(
-                "Channel %s of forward operator not present in " "info." % ch_name
+                f"Channel {ch_name} of forward operator not present in info."
             )
 
     # project the source estimate to the sensor space
@@ -2042,7 +2031,7 @@ def _do_forward_solution(
                 raise ValueError('mindist, if string, must be "all"')
             mindist = ["--all"]
         else:
-            mindist = ["--mindist", "%g" % mindist]
+            mindist = ["--mindist", f"{mindist:g}"]
 
     # src, spacing, bem
     for element, name, kind in zip(
@@ -2051,7 +2040,7 @@ def _do_forward_solution(
         ("path-like", "str", "path-like"),
     ):
         if element is not None:
-            _validate_type(element, kind, name, "%s or None" % kind)
+            _validate_type(element, kind, name, f"{kind} or None")
 
     # put together the actual call
     cmd = [
@@ -2074,7 +2063,7 @@ def _do_forward_solution(
             # allow both "ico4" and "ico-4" style values
             match = re.match(r"(oct|ico)-?(\d+)$", spacing)
             if match is None:
-                raise ValueError("Invalid spacing parameter: %r" % spacing)
+                raise ValueError(f"Invalid spacing parameter: {spacing!r}")
             spacing = "-".join(match.groups())
         cmd += ["--spacing", spacing]
     if mindist is not None:
@@ -2082,9 +2071,9 @@ def _do_forward_solution(
     if bem is not None:
         cmd += ["--bem", bem]
     if mri is not None:
-        cmd += ["--mri", "%s" % str(mri.absolute())]
+        cmd += ["--mri", f"{mri.absolute()}"]
     if trans is not None:
-        cmd += ["--trans", "%s" % str(trans.absolute())]
+        cmd += ["--trans", f"{trans.absolute()}"]
     if not meg:
         cmd.append("--eegonly")
     if not eeg:
@@ -2105,7 +2094,7 @@ def _do_forward_solution(
     try:
         logger.info(
             "Running forward solution generation command with "
-            "subjects_dir %s" % subjects_dir
+            f"subjects_dir {subjects_dir}"
         )
         run_subprocess(cmd, env=env)
     except Exception:
