@@ -1,5 +1,7 @@
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
+
 import inspect
 import os
 import os.path as op
@@ -689,7 +691,7 @@ class CoregistrationUI(HasTraits):
             self._forward_widget_command(locked_widgets, "set_enabled", False)
             self._forward_widget_command(fits_widgets, "set_enabled", False)
             self._display_message(
-                "Placing MRI fiducials - " f"{self._current_fiducial.upper()}"
+                f"Placing MRI fiducials - {self._current_fiducial.upper()}"
             )
 
         self._set_sensors_visibility(self._lock_fids)
@@ -702,7 +704,7 @@ class CoregistrationUI(HasTraits):
         self._follow_fiducial_view()
         if not self._lock_fids:
             self._display_message(
-                "Placing MRI fiducials - " f"{self._current_fiducial.upper()}"
+                f"Placing MRI fiducials - {self._current_fiducial.upper()}"
             )
 
     @observe("_info_file")
@@ -953,7 +955,7 @@ class CoregistrationUI(HasTraits):
         self._update_plot("hsp")
         self._update_distance_estimation()
         self._display_message(
-            f"{n_omitted} head shape points omitted, " f"{n_remaining} remaining."
+            f"{n_omitted} head shape points omitted, {n_remaining} remaining."
         )
 
     def _reset_omit_hsp_filter(self):
@@ -1521,7 +1523,7 @@ class CoregistrationUI(HasTraits):
             except Exception:
                 logger.error(f"Error computing {bem_name} solution")
             else:
-                self._display_message(f"Computing {bem_name} solution..." " Done!")
+                self._display_message(f"Computing {bem_name} solution... Done!")
         self._display_message(f"Saving {self._subject_to}... Done!")
         self._renderer._window_set_cursor(default_cursor)
         self._mri_scale_modified = False
@@ -1704,7 +1706,7 @@ class CoregistrationUI(HasTraits):
             desc="Load",
             func=self._set_info_file,
             icon=True,
-            tooltip="Load the FIFF file with digitization data for " "coregistration",
+            tooltip="Load the FIFF file with digitization data for coregistration",
             layout=info_file_layout,
         )
         self._renderer._layout_add_widget(
@@ -1891,7 +1893,7 @@ class CoregistrationUI(HasTraits):
         self._widgets["fit_icp"] = self._renderer._dock_add_button(
             name="Fit ICP",
             callback=self._fit_icp,
-            tooltip="Find rotation and translation to match the " "head shape points",
+            tooltip="Find rotation and translation to match the head shape points",
             layout=fit_layout,
         )
         self._renderer._layout_add_widget(param_layout, fit_layout)
