@@ -1,6 +1,4 @@
-# Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#         Daniel Strohmeier <daniel.strohmeier@gmail.com>
-#         Mathurin Massias <mathurin.massias@gmail.com>
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -135,7 +133,6 @@ def dgap_l21(M, G, X, active_set, alpha, n_orient):
     return gap, p_obj, d_obj, R
 
 
-@verbose
 def _mixed_norm_solver_cd(
     M,
     G,
@@ -143,7 +140,6 @@ def _mixed_norm_solver_cd(
     lipschitz_constant,
     maxit=10000,
     tol=1e-8,
-    verbose=None,
     init=None,
     n_orient=1,
     dgap_freq=10,
@@ -173,7 +169,6 @@ def _mixed_norm_solver_cd(
     return X, active_set, p_obj
 
 
-@verbose
 def _mixed_norm_solver_bcd(
     M,
     G,
@@ -181,7 +176,6 @@ def _mixed_norm_solver_bcd(
     lipschitz_constant,
     maxit=200,
     tol=1e-8,
-    verbose=None,
     init=None,
     n_orient=1,
     dgap_freq=10,
@@ -419,7 +413,7 @@ def mixed_norm_solver(
     n_positions = n_dipoles // n_orient
     _, n_times = M.shape
     alpha_max = norm_l2inf(np.dot(G.T, M), n_orient, copy=False)
-    logger.info("-- ALPHA MAX : %s" % alpha_max)
+    logger.info(f"-- ALPHA MAX : {alpha_max}")
     alpha = float(alpha)
     X = np.zeros((n_dipoles, n_times), dtype=G.dtype)
 
@@ -667,7 +661,6 @@ def iterative_mixed_norm_solver(
                     active_set_size=active_set_size,
                     dgap_freq=dgap_freq,
                     solver=solver,
-                    verbose=verbose,
                 )
             else:
                 X, _active_set, _ = mixed_norm_solver(
@@ -681,7 +674,6 @@ def iterative_mixed_norm_solver(
                     active_set_size=None,
                     dgap_freq=dgap_freq,
                     solver=solver,
-                    verbose=verbose,
                 )
         else:
             X, _active_set, _ = mixed_norm_solver(
@@ -695,7 +687,6 @@ def iterative_mixed_norm_solver(
                 active_set_size=None,
                 dgap_freq=dgap_freq,
                 solver=solver,
-                verbose=verbose,
             )
 
         logger.info("active set size %d" % (_active_set.sum() / n_orient))
@@ -735,46 +726,6 @@ def iterative_mixed_norm_solver(
 # TF-MxNE
 
 
-@verbose
-def tf_lipschitz_constant(M, G, phi, phiT, tol=1e-3, verbose=None):
-    """Compute lipschitz constant for FISTA.
-
-    It uses a power iteration method.
-    """
-    n_times = M.shape[1]
-    n_points = G.shape[1]
-    iv = np.ones((n_points, n_times), dtype=np.float64)
-    v = phi(iv)
-    L = 1e100
-    for it in range(100):
-        L_old = L
-        logger.info("Lipschitz estimation: iteration = %d" % it)
-        iv = np.real(phiT(v))
-        Gv = np.dot(G, iv)
-        GtGv = np.dot(G.T, Gv)
-        w = phi(GtGv)
-        L = np.max(np.abs(w))  # l_inf norm
-        v = w / L
-        if abs((L - L_old) / L_old) < tol:
-            break
-    return L
-
-
-def safe_max_abs(A, ia):
-    """Compute np.max(np.abs(A[ia])) possible with empty A."""
-    if np.sum(ia):  # ia is not empty
-        return np.max(np.abs(A[ia]))
-    else:
-        return 0.0
-
-
-def safe_max_abs_diff(A, ia, B, ib):
-    """Compute np.max(np.abs(A)) possible with empty A."""
-    A = A[ia] if np.sum(ia) else 0.0
-    B = B[ib] if np.sum(ia) else 0.0
-    return np.max(np.abs(A - B))
-
-
 class _Phi:
     """Have phi stft as callable w/o using a lambda that does not pickle."""
 
@@ -802,9 +753,7 @@ class _Phi:
     def norm(self, z, ord=2):  # noqa: A002
         """Squared L2 norm if ord == 2 and L1 norm if order == 1."""
         if ord not in (1, 2):
-            raise ValueError(
-                "Only supported norm order are 1 and 2. " "Got ord = %s" % ord
-            )
+            raise ValueError(f"Only supported norm order are 1 and 2. Got ord = {ord}")
         stft_norm = stft_norm1 if ord == 1 else stft_norm2
         norm = 0.0
         if len(self.n_coefs) > 1:
@@ -1146,6 +1095,7 @@ def _tf_mixed_norm_solver_bcd_(
     lipschitz_constant,
     phi,
     phiT,
+    *,
     w_space=None,
     w_time=None,
     n_orient=1,
@@ -1153,8 +1103,6 @@ def _tf_mixed_norm_solver_bcd_(
     tol=1e-8,
     dgap_freq=10,
     perc=None,
-    timeit=True,
-    verbose=None,
 ):
     n_sources = G.shape[1]
     n_positions = n_sources // n_orient
@@ -1282,7 +1230,6 @@ def _tf_mixed_norm_solver_bcd_(
     return Z, active_set, E, converged
 
 
-@verbose
 def _tf_mixed_norm_solver_bcd_active_set(
     M,
     G,
@@ -1291,6 +1238,7 @@ def _tf_mixed_norm_solver_bcd_active_set(
     lipschitz_constant,
     phi,
     phiT,
+    *,
     Z_init=None,
     w_space=None,
     w_time=None,
@@ -1298,7 +1246,6 @@ def _tf_mixed_norm_solver_bcd_active_set(
     maxit=200,
     tol=1e-8,
     dgap_freq=10,
-    verbose=None,
 ):
     n_sensors, n_times = M.shape
     n_sources = G.shape[1]
@@ -1310,7 +1257,7 @@ def _tf_mixed_norm_solver_bcd_active_set(
     if Z_init is not None:
         if Z_init.shape != (n_sources, phi.n_coefs.sum()):
             raise Exception(
-                "Z_init must be None or an array with shape " "(n_sources, n_coefs)."
+                "Z_init must be None or an array with shape (n_sources, n_coefs)."
             )
         for ii in range(n_positions):
             if np.any(Z_init[ii * n_orient : (ii + 1) * n_orient]):
@@ -1344,7 +1291,6 @@ def _tf_mixed_norm_solver_bcd_active_set(
             maxit=1,
             tol=tol,
             perc=None,
-            verbose=verbose,
         )
 
         E += E_tmp
@@ -1380,7 +1326,6 @@ def _tf_mixed_norm_solver_bcd_active_set(
             tol=tol,
             dgap_freq=dgap_freq,
             perc=0.5,
-            verbose=verbose,
         )
         active = np.where(active_set[::n_orient])[0]
         active_set[active_set] = as_.copy()
@@ -1535,7 +1480,6 @@ def tf_mixed_norm_solver(
         maxit=maxit,
         tol=tol,
         dgap_freq=dgap_freq,
-        verbose=None,
     )
 
     if np.any(active_set) and debias:
@@ -1548,7 +1492,6 @@ def tf_mixed_norm_solver(
         return X, active_set, E
 
 
-@verbose
 def iterative_tf_mixed_norm_solver(
     M,
     G,
@@ -1677,7 +1620,7 @@ def iterative_tf_mixed_norm_solver(
             w_time = 1.0 / w_time
             w_time[w_time < 0.0] = 0.0
 
-        X, Z, active_set_, E_, _ = _tf_mixed_norm_solver_bcd_active_set(
+        X, Z, active_set_, _, _ = _tf_mixed_norm_solver_bcd_active_set(
             M,
             G[:, active_set],
             alpha_space,
@@ -1692,7 +1635,6 @@ def iterative_tf_mixed_norm_solver(
             maxit=maxit,
             tol=tol,
             dgap_freq=dgap_freq,
-            verbose=None,
         )
 
         active_set[active_set] = active_set_
