@@ -1,12 +1,4 @@
-# Authors: Denis A. Engemann  <denis.engemann@gmail.com>
-#          Martin Luessi <mluessi@nmr.mgh.harvard.edu>
-#          Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Matti Hämäläinen <msh@nmr.mgh.harvard.edu>
-#          Yuval Harpaz <yuvharpaz@gmail.com>
-#          Joan Massich <mailsik@gmail.com>
-#          Teon Brooks <teon.brooks@gmail.com>
-#
-#          simplified BSD-3 license
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -42,9 +34,6 @@ from .read import (
     read_uint32,
 )
 
-FIFF_INFO_DIG_FIELDS = ("kind", "ident", "r", "coord_frame")
-FIFF_INFO_DIG_DEFAULTS = (None, None, None, FIFF.FIFFV_COORD_HEAD)
-
 BTI_WH2500_REF_MAG = ("MxA", "MyA", "MzA", "MxaA", "MyaA", "MzaA")
 BTI_WH2500_REF_GRAD = ("GxxA", "GyyA", "GyxA", "GzaA", "GzyA")
 
@@ -187,7 +176,7 @@ def _check_nan_dev_head_t(dev_ctf_t):
     has_nan = np.isnan(dev_ctf_t["trans"])
     if np.any(has_nan):
         logger.info(
-            "Missing values BTI dev->head transform. " "Replacing with identity matrix."
+            "Missing values BTI dev->head transform. Replacing with identity matrix."
         )
         dev_ctf_t["trans"] = np.identity(4)
 
@@ -287,14 +276,14 @@ def _read_config(fname):
                 elif kind == BTI.UB_B_COH_POINTS:
                     dta["n_points"] = read_int32(fid)
                     dta["status"] = read_int32(fid)
-                    dta["points"] = []
-                    for pnt in range(16):
-                        d = {
+                    dta["points"] = [
+                        {
                             "pos": read_double_matrix(fid, 1, 3),
                             "direction": read_double_matrix(fid, 1, 3),
                             "error": read_double(fid),
                         }
-                        dta["points"] += [d]
+                        for _ in range(16)
+                    ]
 
                 elif kind == BTI.UB_B_CCP_XFM_BLOCK:
                     dta["method"] = read_int32(fid)
@@ -330,8 +319,8 @@ def _read_config(fname):
 
                     if num_channels is None:
                         raise ValueError(
-                            "Cannot find block %s to determine "
-                            "number of channels" % BTI.UB_B_WHC_CHAN_MAP_VER
+                            f"Cannot find block {BTI.UB_B_WHC_CHAN_MAP_VER} to "
+                            "determine number of channels"
                         )
 
                     dta["channels"] = list()
@@ -355,12 +344,12 @@ def _read_config(fname):
 
                     if num_subsys is None:
                         raise ValueError(
-                            "Cannot find block %s to determine"
-                            " number of subsystems" % BTI.UB_B_WHS_SUBSYS_VER
+                            f"Cannot find block {BTI.UB_B_WHS_SUBSYS_VER} to determine"
+                            " number of subsystems"
                         )
 
                     dta["subsys"] = list()
-                    for sub_key in range(num_subsys):
+                    for _ in range(num_subsys):
                         d = {
                             "subsys_type": read_int16(fid),
                             "subsys_num": read_int16(fid),
@@ -573,7 +562,7 @@ def _read_config(fname):
                 fid.seek(4, 1)
                 dev["reserved"] = read_str(fid, 32)
                 dta.update({"dev": dev, "loops": []})
-                for loop in range(dev["total_loops"]):
+                for _ in range(dev["total_loops"]):
                     d = {
                         "position": read_double_matrix(fid, 1, 3),
                         "orientation": read_double_matrix(fid, 1, 3),
@@ -774,82 +763,6 @@ def _read_pfid_ed(fid):
     return out
 
 
-def _read_coil_def(fid):
-    """Read coil definition."""
-    coildef = {
-        "position": read_double_matrix(fid, 1, 3),
-        "orientation": read_double_matrix(fid, 1, 3),
-        "radius": read_double(fid),
-        "wire_radius": read_double(fid),
-        "turns": read_int16(fid),
-    }
-
-    fid.seek(fid, 2, 1)
-    coildef["checksum"] = read_int32(fid)
-    coildef["reserved"] = read_str(fid, 32)
-
-
-def _read_ch_config(fid):
-    """Read BTi channel config."""
-    cfg = {
-        "name": read_str(fid, BTI.FILE_CONF_CH_NAME),
-        "chan_no": read_int16(fid),
-        "ch_type": read_uint16(fid),
-        "sensor_no": read_int16(fid),
-    }
-
-    fid.seek(fid, BTI.FILE_CONF_CH_NEXT, 1)
-
-    cfg.update(
-        {
-            "gain": read_float(fid),
-            "units_per_bit": read_float(fid),
-            "yaxis_label": read_str(fid, BTI.FILE_CONF_CH_YLABEL),
-            "aar_val": read_double(fid),
-            "checksum": read_int32(fid),
-            "reserved": read_str(fid, BTI.FILE_CONF_CH_RESERVED),
-        }
-    )
-
-    _correct_offset(fid)
-
-    # Then the channel info
-    ch_type, chan = cfg["ch_type"], dict()
-    chan["dev"] = {
-        "size": read_int32(fid),
-        "checksum": read_int32(fid),
-        "reserved": read_str(fid, 32),
-    }
-    if ch_type in [BTI.CHTYPE_MEG, BTI.CHTYPE_REF]:
-        chan["loops"] = [_read_coil_def(fid) for d in range(chan["dev"]["total_loops"])]
-
-    elif ch_type == BTI.CHTYPE_EEG:
-        chan["impedance"] = read_float(fid)
-        chan["padding"] = read_str(fid, BTI.FILE_CONF_CH_PADDING)
-        chan["transform"] = read_transform(fid)
-        chan["reserved"] = read_char(fid, BTI.FILE_CONF_CH_RESERVED)
-
-    elif ch_type in [
-        BTI.CHTYPE_TRIGGER,
-        BTI.CHTYPE_EXTERNAL,
-        BTI.CHTYPE_UTILITY,
-        BTI.CHTYPE_DERIVED,
-    ]:
-        chan["user_space_size"] = read_int32(fid)
-        if ch_type == BTI.CHTYPE_TRIGGER:
-            fid.seek(2, 1)
-        chan["reserved"] = read_str(fid, BTI.FILE_CONF_CH_RESERVED)
-
-    elif ch_type == BTI.CHTYPE_SHORTED:
-        chan["reserved"] = read_str(fid, BTI.FILE_CONF_CH_RESERVED)
-
-    cfg["chan"] = chan
-
-    _correct_offset(fid)
-
-    return cfg
-
-
 def _read_bti_header_pdf(pdf_fname):
     """Read header from pdf file."""
     with _bti_open(pdf_fname, "rb") as fid:
@@ -908,22 +821,20 @@ def _read_bti_header_pdf(pdf_fname):
 
         # actual header ends here, so dar seems ok.
 
-        info["epochs"] = [_read_epoch(fid) for epoch in range(info["total_epochs"])]
+        info["epochs"] = [_read_epoch(fid) for _ in range(info["total_epochs"])]
 
-        info["chs"] = [_read_channel(fid) for ch in range(info["total_chans"])]
+        info["chs"] = [_read_channel(fid) for _ in range(info["total_chans"])]
 
-        info["events"] = [_read_event(fid) for event in range(info["total_events"])]
+        info["events"] = [_read_event(fid) for _ in range(info["total_events"])]
 
-        info["processes"] = [
-            _read_process(fid) for process in range(info["total_processes"])
-        ]
+        info["processes"] = [_read_process(fid) for _ in range(info["total_processes"])]
 
         info["assocfiles"] = [
-            _read_assoc_file(fid) for af in range(info["total_associated_files"])
+            _read_assoc_file(fid) for _ in range(info["total_associated_files"])
         ]
 
         info["edclasses"] = [
-            _read_pfid_ed(fid) for ed_class in range(info["total_ed_classes"])
+            _read_pfid_ed(fid) for _ in range(info["total_ed_classes"])
         ]
 
         info["extra_data"] = fid.read(start - fid.tell())
@@ -1164,7 +1075,7 @@ def _make_bti_digitization(
 ):
     with info._unlock():
         if head_shape_fname:
-            logger.info("... Reading digitization points from %s" % head_shape_fname)
+            logger.info(f"... Reading digitization points from {head_shape_fname}")
 
             nasion, lpa, rpa, hpi, dig_points = _read_head_shape(head_shape_fname)
             info["dig"], dev_head_t, ctf_head_t = _make_bti_dig_points(
@@ -1217,9 +1128,7 @@ def _get_bti_info(
 
     """
     if pdf_fname is None:
-        logger.info(
-            "No pdf_fname passed, trying to construct partial info " "from config"
-        )
+        logger.info("No pdf_fname passed, trying to construct partial info from config")
     if pdf_fname is not None and not isinstance(pdf_fname, BytesIO):
         if not op.isabs(pdf_fname):
             pdf_fname = op.abspath(pdf_fname)
@@ -1236,9 +1145,9 @@ def _get_bti_info(
                     break
         if not op.isfile(config_fname):
             raise ValueError(
-                "Could not find the config file %s. Please check"
+                f"Could not find the config file {config_fname}. Please check"
                 " whether you are in the right directory "
-                "or pass the full name" % config_fname
+                "or pass the full name"
             )
 
     if head_shape_fname is not None and not isinstance(head_shape_fname, BytesIO):
@@ -1248,13 +1157,13 @@ def _get_bti_info(
 
         if not op.isfile(head_shape_fname):
             raise ValueError(
-                'Could not find the head_shape file "%s". '
+                f'Could not find the head_shape file "{orig_name}". '
                 "You should check whether you are in the "
                 "right directory, pass the full file name, "
-                "or pass head_shape_fname=None." % orig_name
+                "or pass head_shape_fname=None."
             )
 
-    logger.info("Reading 4D PDF file %s..." % pdf_fname)
+    logger.info(f"Reading 4D PDF file {pdf_fname}...")
     bti_info = _read_bti_header(
         pdf_fname, config_fname, sort_by_ch_name=sort_by_ch_name
     )
@@ -1339,7 +1248,7 @@ def _get_bti_info(
                 if convert:
                     if idx == 0:
                         logger.info(
-                            "... putting coil transforms in Neuromag " "coordinates"
+                            "... putting coil transforms in Neuromag coordinates"
                         )
                     t = _loc_to_coil_trans(bti_info["chs"][idx]["loc"])
                     t = _convert_coil_trans(t, dev_ctf_t, bti_dev_t)
