@@ -1,8 +1,5 @@
-# -*- coding: UTF-8 -*-
-#
-# Authors: Dirk Gütlin <dirk.guetlin@stud.sbg.ac.at>
-#
 #
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -68,7 +65,7 @@ SI_UNIT_SCALE = dict(c=1e-2, m=1e-3, u=1e-6, µ=1e-6, n=1e-9, p=1e-12, f=1e-15)
 
 CurryParameters = namedtuple(
     "CurryParameters",
-    "n_samples, sfreq, is_ascii, unit_dict, " "n_chans, dt_start, chanidx_in_file",
+    "n_samples, sfreq, is_ascii, unit_dict, n_chans, dt_start, chanidx_in_file",
 )
 
 
@@ -608,8 +605,8 @@ class RawCurry(BaseRaw):
 
         if "events" in curry_paths:
             logger.info(
-                "Event file found. Extracting Annotations from"
-                " %s..." % curry_paths["events"]
+                "Event file found. Extracting Annotations from "
+                f"{curry_paths['events']}..."
             )
             annots = _read_annotations_curry(
                 curry_paths["events"], sfreq=self.info["sfreq"]
