@@ -1,19 +1,12 @@
 """Reading tools from EDF, EDF+, BDF, and GDF."""
 
-# Authors: Teon Brooks <teon.brooks@gmail.com>
-#          Martin Billinger <martin.billinger@tugraz.at>
-#          Nicolas Barascud <nicolas.barascud@ens.fr>
-#          Stefan Appelhoff <stefan.appelhoff@mailbox.org>
-#          Joan Massich <mailsik@gmail.com>
-#          Clemens Brunner <clemens.brunner@gmail.com>
-#          Jeroen Van Der Donckt (IDlab - imec) <jeroen.vanderdonckt@ugent.be>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
 import os
 import re
-from datetime import datetime, timedelta, timezone
+from datetime import date, datetime, timedelta, timezone
 
 import numpy as np
 from scipy.interpolate import interp1d
@@ -513,7 +506,7 @@ def _read_header(fname, exclude, infer_types, include=None, exclude_after_unique
     (edf_info, orig_units) : tuple
     """
     ext = os.path.splitext(fname)[1][1:].lower()
-    logger.info("%s file detected" % ext.upper())
+    logger.info(f"{ext.upper()} file detected")
     if ext in ("bdf", "edf"):
         return _read_edf_header(
             fname, exclude, infer_types, include, exclude_after_unique
@@ -690,7 +683,7 @@ def _get_info(
             info["subject_info"]["last_name"] = sub_names[2]
     # Birthday in (year, month, day) format.
     if isinstance(edf_info["subject_info"].get("birthday"), datetime):
-        info["subject_info"]["birthday"] = (
+        info["subject_info"]["birthday"] = date(
             edf_info["subject_info"]["birthday"].year,
             edf_info["subject_info"]["birthday"].month,
             edf_info["subject_info"]["birthday"].day,
@@ -704,6 +697,9 @@ def _get_info(
     # Weight in kilograms.
     if edf_info["subject_info"].get("weight") is not None:
         info["subject_info"]["weight"] = float(edf_info["subject_info"]["weight"])
+    # Remove values after conversion to help with in-memory anonymization
+    for key in ("subject_info", "meas_date"):
+        del edf_info[key]
 
     # Filter settings
     if filt_ch_idxs := [x for x in range(len(sel)) if x not in stim_channel_idxs]:
@@ -835,48 +831,40 @@ def _read_edf_header(
                                 warn(f"Invalid patient information {key}")
 
         # Recording ID
-        meas_id = {}
         rec_info = fid.read(80).decode("latin-1").rstrip().split(" ")
-        valid_startdate = False
+        # if the measurement date is available in the recording info, it's used instead
+        # of the file's meas_date since it contains all 4 digits of the year.
+        meas_date = None
         if len(rec_info) == 5:
             try:
-                startdate = datetime.strptime(rec_info[1], "%d-%b-%Y")
-            except ValueError:
-                startdate = "X"
+                meas_date = datetime.strptime(rec_info[1], "%d-%b-%Y")
+            except Exception:
+                meas_date = None
             else:
-                valid_startdate = True
-            meas_id["startdate"] = startdate
-            meas_id["study_id"] = rec_info[2]
-            meas_id["technician"] = rec_info[3]
-            meas_id["equipment"] = rec_info[4]
-
-        # If startdate available in recording info, use it instead of the
-        # file's meas_date since it contains all 4 digits of the year
-        if valid_startdate:
-            day = meas_id["startdate"].day
-            month = meas_id["startdate"].month
-            year = meas_id["startdate"].year
-            fid.read(8)  # skip file's meas_date
+                fid.read(8)  # skip the file's meas_date
+        if meas_date is None:
+            try:
+                meas_date = fid.read(8).decode("latin-1")
+                day, month, year = (int(x) for x in meas_date.split("."))
+                year = year + 2000 if year < 85 else year + 1900
+                meas_date = datetime(year, month, day)
+            except Exception:
+                meas_date = None
+        if meas_date is not None:
+            # try to get the hour/minute/sec from the recording info
+            try:
+                meas_time = fid.read(8).decode("latin-1")
+                hour, minute, second = (int(x) for x in meas_time.split("."))
+            except Exception:
+                hour, minute, second = 0, 0, 0
+            meas_date = meas_date.replace(
+                hour=hour, minute=minute, second=second, tzinfo=timezone.utc
+            )
         else:
-            meas_date = fid.read(8).decode("latin-1")
-            day, month, year = (int(x) for x in meas_date.split("."))
-            year = year + 2000 if year < 85 else year + 1900
-
-        meas_time = fid.read(8).decode("latin-1")
-        hour, minute, sec = (int(x) for x in meas_time.split("."))
-        try:
-            meas_date = datetime(
-                year, month, day, hour, minute, sec, tzinfo=timezone.utc
-            )
-        except ValueError:
-            warn(
-                f"Invalid date encountered ({year:04d}-{month:02d}-"
-                f"{day:02d} {hour:02d}:{minute:02d}:{sec:02d})."
-            )
-            meas_date = None
+            fid.read(8)  # skip the file's measurement time
+            warn("Invalid measurement date encountered in the header.")
 
         header_nbytes = int(_edf_str(fid.read(8)))
-
         # The following 44 bytes sometimes identify the file type, but this is
         # not guaranteed. Therefore, we skip this field and use the file
         # extension to determine the subtype (EDF or BDF, which differ in the
@@ -1354,9 +1342,9 @@ def _read_gdf_header(fname, exclude, include=None):
                     edf_info["units"].append(1)  # unrecognized
                 else:
                     warn(
-                        "Unsupported physical dimension for channel %d "
+                        f"Unsupported physical dimension for channel {i} "
                         "(assuming dimensionless). Please contact the "
-                        "MNE-Python developers for support." % i
+                        "MNE-Python developers for support."
                     )
                     edf_info["units"].append(1)
             edf_info["units"] = np.array(edf_info["units"], float)
@@ -1548,7 +1536,7 @@ def _find_exclude_idx(ch_names, exclude, include=None):
     if include:  # find other than include channels
         if exclude:
             raise ValueError(
-                "'exclude' must be empty if 'include' is assigned. " f"Got {exclude}."
+                f"'exclude' must be empty if 'include' is assigned. Got {exclude}."
             )
         if isinstance(include, str):  # regex for channel names
             indices_include = []
