@@ -1,7 +1,4 @@
-# Authors: Mainak Jas <mainak.jas@telecom-paristech.fr>
-#          Jona Sassenhagen <jona.sassenhagen@gmail.com>
-#          Stefan Appelhoff <stefan.appelhoff@mailbox.org>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -234,7 +231,7 @@ def _get_info(eeg, *, eog, montage_units):
         )
         update_ch_names = False
     else:  # if eeg.chanlocs is empty, we still need default chan names
-        ch_names = ["EEG %03d" % ii for ii in range(eeg.nbchan)]
+        ch_names = [f"EEG {ii:03d}" for ii in range(eeg.nbchan)]
         ch_types = "eeg"
         eeg_montage = None
         update_ch_names = True
@@ -385,7 +382,7 @@ def read_epochs_eeglab(
 
     Returns
     -------
-    epochs : instance of Epochs
+    EpochsEEGLAB : instance of BaseEpochs
         The epochs.
 
     See Also
@@ -452,9 +449,9 @@ class RawEEGLAB(BaseRaw):
         eeg = _check_load_mat(input_fname, uint16_codec)
         if eeg.trials != 1:
             raise TypeError(
-                "The number of trials is %d. It must be 1 for raw"
+                f"The number of trials is {eeg.trials:d}. It must be 1 for raw"
                 " files. Please use `mne.io.read_epochs_eeglab` if"
-                " the .set file contains epochs." % eeg.trials
+                " the .set file contains epochs."
             )
 
         last_samps = [eeg.pnts - 1]
@@ -463,7 +460,7 @@ class RawEEGLAB(BaseRaw):
         # read the data
         if isinstance(eeg.data, str):
             data_fname = _check_eeglab_fname(input_fname, eeg.data)
-            logger.info("Reading %s" % data_fname)
+            logger.info(f"Reading {data_fname}")
 
             super().__init__(
                 info,
@@ -610,7 +607,7 @@ class EpochsEEGLAB(BaseEpochs):
             (events is None and event_id is None)
             or (events is not None and event_id is not None)
         ):
-            raise ValueError("Both `events` and `event_id` must be " "None or not None")
+            raise ValueError("Both `events` and `event_id` must be None or not None")
 
         if eeg.trials <= 1:
             raise ValueError(
@@ -668,14 +665,12 @@ class EpochsEEGLAB(BaseEpochs):
         elif isinstance(events, (str, Path, PathLike)):
             events = read_events(events)
 
-        logger.info("Extracting parameters from %s..." % input_fname)
+        logger.info(f"Extracting parameters from {input_fname}...")
         info, eeg_montage, _ = _get_info(eeg, eog=eog, montage_units=montage_units)
 
         for key, val in event_id.items():
             if val not in events[:, 2]:
-                raise ValueError(
-                    "No matching events found for %s " "(event id %i)" % (key, val)
-                )
+                raise ValueError(f"No matching events found for {key} (event id {val})")
 
         if isinstance(eeg.data, str):
             data_fname = _check_eeglab_fname(input_fname, eeg.data)
