@@ -3,10 +3,7 @@
 RawKIT class is adapted from Denis Engemann et al.'s mne_bti2fiff.py.
 """
 
-# Authors: Teon Brooks <teon.brooks@gmail.com>
-#          Joan Massich <mailsik@gmail.com>
-#          Christian Brodbeck <christianbrodbeck@nyu.edu>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -70,7 +67,7 @@ def _call_digitization(info, mrk, elp, hsp, kit_info, *, bad_coils=()):
             )
     elif mrk is not None or elp is not None or hsp is not None:
         raise ValueError(
-            "mrk, elp and hsp need to be provided as a group " "(all or none)"
+            "mrk, elp and hsp need to be provided as a group (all or none)"
         )
 
     return info
@@ -142,7 +139,7 @@ class RawKIT(BaseRaw):
         bad_coils=(),
         verbose=None,
     ):
-        logger.info("Extracting SQD Parameters from %s..." % input_fname)
+        logger.info(f"Extracting SQD Parameters from {input_fname}...")
         input_fname = op.abspath(input_fname)
         self.preload = False
         logger.info("Creating Raw.info structure...")
@@ -152,7 +149,7 @@ class RawKIT(BaseRaw):
         kit_info["slope"] = slope
         kit_info["stimthresh"] = stimthresh
         if kit_info["acq_type"] != KIT.CONTINUOUS:
-            raise TypeError("SQD file contains epochs, not raw data. Wrong " "reader.")
+            raise TypeError("SQD file contains epochs, not raw data. Wrong reader.")
         logger.info("Creating Info structure...")
 
         last_samps = [kit_info["n_samples"] - 1]
@@ -276,7 +273,7 @@ def _set_stimchannels(inst, info, stim, stim_code):
                 stim = picks
             else:
                 raise ValueError(
-                    "stim needs to be list of int, '>' or " "'<', not %r" % str(stim)
+                    f"stim needs to be list of int, '>' or '<', not {str(stim)!r}"
                 )
         else:
             stim = np.asarray(stim, int)
@@ -327,7 +324,7 @@ def _make_stim_channel(trigger_chs, slope, threshold, stim_code, trigger_values)
         trigger_values = 2 ** np.arange(len(trigger_chs))
     elif stim_code != "channel":
         raise ValueError(
-            "stim_code must be 'binary' or 'channel', got %s" % repr(stim_code)
+            f"stim_code must be 'binary' or 'channel', got {repr(stim_code)}"
         )
     trig_chs = trig_chs_bin * trigger_values[:, np.newaxis]
     return np.array(trig_chs.sum(axis=0), ndmin=2)
@@ -401,7 +398,7 @@ class EpochsKIT(BaseEpochs):
         input_fname = str(
             _check_fname(fname=input_fname, must_exist=True, overwrite="read")
         )
-        logger.info("Extracting KIT Parameters from %s..." % input_fname)
+        logger.info(f"Extracting KIT Parameters from {input_fname}...")
         self.info, kit_info = get_kit_info(
             input_fname, allow_unknown_format, standardize_names
         )
@@ -415,7 +412,7 @@ class EpochsKIT(BaseEpochs):
             self._raw_extras[0]["data_length"] = KIT.INT
         else:
             raise TypeError(
-                "SQD file contains raw data, not epochs or " "average. Wrong reader."
+                "SQD file contains raw data, not epochs or average. Wrong reader."
             )
 
         if event_id is None:  # convert to int to make typing-checks happy
@@ -423,9 +420,7 @@ class EpochsKIT(BaseEpochs):
 
         for key, val in event_id.items():
             if val not in events[:, 2]:
-                raise ValueError(
-                    "No matching events found for %s " "(event id %i)" % (key, val)
-                )
+                raise ValueError(f"No matching events found for {key} (event id {val})")
 
         data = self._read_kit_data()
         assert data.shape == (
@@ -543,7 +538,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
             version_string = "V%iR%03i" % (version, revision)
             if allow_unknown_format:
                 unsupported_format = True
-                warn("Force loading KIT format %s" % version_string)
+                warn(f"Force loading KIT format {version_string}")
             else:
                 raise UnsupportedKITFormat(
                     version_string,
@@ -560,6 +555,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
         sqd["nchan"] = channel_count = int(np.fromfile(fid, INT32, 1)[0])
         comment = _read_name(fid, n=256)
         create_time, last_modified_time = np.fromfile(fid, INT32, 2)
+        del last_modified_time
         fid.seek(KIT.INT * 3, SEEK_CUR)  # reserved
         dewar_style = np.fromfile(fid, INT32, 1)[0]
         fid.seek(KIT.INT * 3, SEEK_CUR)  # spare
@@ -575,6 +571,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
         else:
             adc_range = np.fromfile(fid, FLOAT64, 1)[0]
         adc_polarity, adc_allocated, adc_stored = np.fromfile(fid, INT32, 3)
+        del adc_polarity
         system_name = system_name.replace("\x00", "")
         system_name = system_name.strip().replace("\n", "/")
         model_name = model_name.replace("\x00", "")
@@ -793,6 +790,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
                     mri_type, meg_type, mri_done, this_meg_done = np.fromfile(
                         fid, INT32, 4
                     )
+                    del mri_type, meg_type, mri_done
                     meg_done[mi] = bool(this_meg_done)
                     fid.seek(3 * KIT.DOUBLE, SEEK_CUR)  # mri_pos
                     mrk[mi] = np.fromfile(fid, FLOAT64, 3)
@@ -1022,9 +1020,13 @@ def read_epochs_kit(
 
     Returns
     -------
-    epochs : instance of Epochs
+    EpochsKIT : instance of BaseEpochs
         The epochs.
 
+    See Also
+    --------
+    mne.Epochs : Documentation of attributes and methods.
+
     Notes
     -----
     .. versionadded:: 0.9.0
