@@ -1,5 +1,4 @@
-# Authors: Federico Raimondo <federaimondo@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -184,7 +183,7 @@ def _read_nihon_header(fname):
         fid.seek(0x17FE)
         waveform_sign = np.fromfile(fid, np.uint8, 1)[0]
         if waveform_sign != 1:
-            raise ValueError("Not a valid Nihon Kohden EEG file " "(waveform block)")
+            raise ValueError("Not a valid Nihon Kohden EEG file (waveform block)")
         header["version"] = version
 
         fid.seek(0x0091)
@@ -267,11 +266,11 @@ def _read_nihon_header(fname):
                 )
             if block_0["channels"] != t_block["channels"]:
                 raise ValueError(
-                    "Cannot read NK file with different channels in each " "datablock"
+                    "Cannot read NK file with different channels in each datablock"
                 )
             if block_0["sfreq"] != t_block["sfreq"]:
                 raise ValueError(
-                    "Cannot read NK file with different sfreq in each " "datablock"
+                    "Cannot read NK file with different sfreq in each datablock"
                 )
 
     return header
@@ -382,7 +381,7 @@ class RawNihon(BaseRaw):
     def __init__(self, fname, preload=False, verbose=None):
         fname = _check_fname(fname, "read", True, "fname")
         data_name = fname.name
-        logger.info("Loading %s" % data_name)
+        logger.info(f"Loading {data_name}")
 
         header = _read_nihon_header(fname)
         metadata = _read_nihon_metadata(fname)
