@@ -1,7 +1,6 @@
 """Generic tests that all raw classes should run."""
-# Authors: MNE Developers
-#          Stefan Appelhoff <stefan.appelhoff@mailbox.org>
-#
+
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -30,7 +29,6 @@ from mne._fiff.meas_info import Info, _get_valid_units, _writing_info_hdf5
 from mne._fiff.pick import _ELECTRODE_CH_TYPES, _FNIRS_CH_TYPES_SPLIT
 from mne._fiff.proj import Projection
 from mne._fiff.utils import _mult_cal_one
-from mne.fixes import _numpy_h5py_dep
 from mne.io import BaseRaw, RawArray, read_raw_fif
 from mne.io.base import _get_scaling
 from mne.transforms import Transform
@@ -335,7 +333,7 @@ def _test_raw_reader(
     assert meas_date is None or meas_date >= _stamp_to_dt((0, 0))
 
     # test repr_html
-    assert "Good channels" in raw._repr_html_()
+    assert "Channels" in raw._repr_html_()
 
     # test resetting raw
     if test_kwargs:
@@ -441,7 +439,7 @@ def _test_raw_reader(
     if check_version("h5io"):
         read_hdf5, write_hdf5 = _import_h5io_funcs()
         fname_h5 = op.join(tempdir, "info.h5")
-        with _writing_info_hdf5(raw.info), _numpy_h5py_dep():
+        with _writing_info_hdf5(raw.info):
             write_hdf5(fname_h5, raw.info)
             new_info = Info(read_hdf5(fname_h5))
         assert object_diff(new_info, raw.info) == ""
