@@ -1,7 +1,7 @@
-# Authors: Olaf Hauk <olaf.hauk@mrc-cbu.cam.ac.uk>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
+
 """Compute resolution metrics from resolution matrix.
 
 Resolution metrics: localisation error, spatial extent, relative amplitude.
@@ -79,10 +79,10 @@ def resolution_metrics(
     # Check if input options are valid
     metrics = ("peak_err", "cog_err", "sd_ext", "maxrad_ext", "peak_amp", "sum_amp")
     if metric not in metrics:
-        raise ValueError('"%s" is not a recognized metric.' % metric)
+        raise ValueError(f'"{metric}" is not a recognized metric.')
 
     if function not in ["psf", "ctf"]:
-        raise ValueError("Not a recognised resolution function: %s." % function)
+        raise ValueError(f"Not a recognised resolution function: {function}.")
 
     if metric in ("peak_err", "cog_err"):
         resolution_metric = _localisation_error(
@@ -310,16 +310,14 @@ def _rectify_resolution_matrix(resmat):
     if not shape[0] == shape[1]:
         if shape[0] < shape[1]:
             raise ValueError(
-                "Number of target sources (%d) cannot be lower "
-                "than number of input sources (%d)" % shape[0],
-                shape[1],
+                f"Number of target sources ({shape[0]}) cannot be lower "
+                f"than number of input sources ({shape[1]})"
             )
 
         if np.mod(shape[0], shape[1]):  # if ratio not integer
             raise ValueError(
-                "Number of target sources (%d) must be a "
-                "multiple of the number of input sources (%d)" % shape[0],
-                shape[1],
+                f"Number of target sources ({shape[0]}) must be a "
+                f"multiple of the number of input sources ({shape[1]})"
             )
 
         ns = shape[0] // shape[1]  # number of source components per vertex
