@@ -1,7 +1,4 @@
-# Author(s): Tommy Clausner <tommy.clausner@gmail.com>
-#            Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#            Eric Larson <larson.eric.d@gmail.com>
-
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -12,7 +9,7 @@ import warnings
 import numpy as np
 from scipy import sparse
 
-from .fixes import _get_img_fdata
+from .fixes import _eye_array, _get_img_fdata
 from .morph_map import read_morph_map
 from .parallel import parallel_func
 from .source_estimate import (
@@ -207,7 +204,7 @@ def compute_source_morph(
             "with surface source estimates."
         )
     if sparse and kind != "surface":
-        raise ValueError("Only surface source estimates can compute a " "sparse morph.")
+        raise ValueError("Only surface source estimates can compute a sparse morph.")
 
     subjects_dir = str(get_subjects_dir(subjects_dir, raise_error=True))
     shape = affine = pre_affine = sdr_morph = morph_mat = None
@@ -223,7 +220,7 @@ def compute_source_morph(
         mri_subpath = op.join("mri", "brain.mgz")
         mri_path_from = op.join(subjects_dir, subject_from, mri_subpath)
 
-        logger.info('    Loading %s as "from" volume' % mri_path_from)
+        logger.info(f'    Loading {mri_path_from} as "from" volume')
         with warnings.catch_warnings():
             mri_from = nib.load(mri_path_from)
 
@@ -231,8 +228,8 @@ def compute_source_morph(
         # let's KISS and use `brain.mgz`, too
         mri_path_to = op.join(subjects_dir, subject_to, mri_subpath)
         if not op.isfile(mri_path_to):
-            raise OSError("cannot read file: %s" % mri_path_to)
-        logger.info('    Loading %s as "to" volume' % mri_path_to)
+            raise OSError(f"cannot read file: {mri_path_to}")
+        logger.info(f'    Loading {mri_path_to} as "to" volume')
         with warnings.catch_warnings():
             mri_to = nib.load(mri_path_to)
 
@@ -340,7 +337,7 @@ def _compute_sparse_morph(vertices_from, subject_from, subject_to, subjects_dir=
     cols = np.concatenate(cols)
     rows = np.arange(len(cols))
     data = np.ones(len(cols))
-    morph_mat = sparse.coo_matrix(
+    morph_mat = sparse.coo_array(
         (data, (rows, cols)), shape=(len(cols), len(cols))
     ).tocsr()
     return vertices, morph_mat
@@ -404,7 +401,7 @@ class SourceMorph:
         See :func:`mne.compute_source_morph`.
     xhemi : bool
         Morph across hemisphere.
-    morph_mat : scipy.sparse.csr_matrix
+    morph_mat : scipy.sparse.csr_array
         The sparse surface morphing matrix for spherical surface
         based morphing :footcite:`GreveEtAl2013`.
     vertices_to : list of ndarray
@@ -420,7 +417,7 @@ class SourceMorph:
         (SDR) morph.
     src_data : dict
         Additional source data necessary to perform morphing.
-    vol_morph_mat : scipy.sparse.csr_matrix | None
+    vol_morph_mat : scipy.sparse.csr_array | None
         The volumetric morph matrix, if :meth:`compute_vol_morph_mat`
         was used.
     %(verbose)s
@@ -587,7 +584,7 @@ class SourceMorph:
         -----
         For a volumetric morph, this will compute the morph for an identity
         source volume, i.e., with one source vertex active at a time, and store
-        the result as a :class:`sparse <scipy.sparse.csr_matrix>`
+        the result as a :class:`sparse <scipy.sparse.csr_array>`
         morphing matrix. This takes a long time (minutes) to compute initially,
         but drastically speeds up :meth:`apply` for STCs, so it can be
         beneficial when many time points or many morphs (i.e., greater than
@@ -602,9 +599,7 @@ class SourceMorph:
         """
         if self.affine is None or self.vol_morph_mat is not None:
             return
-        logger.info(
-            "Computing sparse volumetric morph matrix " "(will take some time...)"
-        )
+        logger.info("Computing sparse volumetric morph matrix (will take some time...)")
         self.vol_morph_mat = self._morph_vols(None, "Vertex")
         return self
 
@@ -660,7 +655,7 @@ class SourceMorph:
             for attr in attrs:
                 # transform from source space to mri_from resolution/space
                 if vols is None:
-                    img_real = interp[:, ii]
+                    img_real = interp[:, [ii]]
                 else:
                     img_real = interp @ getattr(vols[:, ii], attr)
                 _debug_img(img_real, from_affine, "From", src_shape)
@@ -730,12 +725,12 @@ class SourceMorph:
                         img_to[:, ii] = img_to[:, ii] + 1j * img_real
 
         if vols is None:
-            img_to = sparse.csc_matrix(img_to, shape=(len(vol_verts), n_vols)).tocsr()
+            img_to = sparse.csc_array(img_to, shape=(len(vol_verts), n_vols)).tocsr()
 
         return img_to
 
     def __repr__(self):  # noqa: D105
-        s = "%s" % self.kind
+        s = f"{self.kind}"
         s += f", {self.subject_from} -> {self.subject_to}"
         if self.kind == "volume":
             s += f", zooms : {self.zooms}"
@@ -746,7 +741,7 @@ class SourceMorph:
             s += f", smooth : {self.smooth}"
             s += ", xhemi" if self.xhemi else ""
 
-        return "<SourceMorph | %s>" % s
+        return f"<SourceMorph | {s}>"
 
     @verbose
     def save(self, fname, overwrite=False, verbose=None):
@@ -808,17 +803,17 @@ def _check_zooms(mri_from, zooms, zooms_src_to):
     return zooms
 
 
-def _resample_from_to(img, affine, to_vox_map):
-    # Wrap to dipy for speed, equivalent to:
-    # from nibabel.processing import resample_from_to
-    # from nibabel.spatialimages import SpatialImage
-    # return _get_img_fdata(
-    #     resample_from_to(SpatialImage(img, affine), to_vox_map, order=1))
-    import dipy.align.imaffine
-
-    return dipy.align.imaffine.AffineMap(
-        None, to_vox_map[0], to_vox_map[1], img.shape, affine
-    ).transform(img, resample_only=True)
+# def _resample_from_to(img, affine, to_vox_map):
+#     # Wrap to dipy for speed, equivalent to:
+#     # from nibabel.processing import resample_from_to
+#     # from nibabel.spatialimages import SpatialImage
+#     # return _get_img_fdata(
+#     #     resample_from_to(SpatialImage(img, affine), to_vox_map, order=1))
+#     import dipy.align.imaffine
+#
+#     return dipy.align.imaffine.AffineMap(
+#         None, to_vox_map[0], to_vox_map[1], img.shape, affine
+#     ).transform(img, resample_only=True)
 
 
 ###############################################################################
@@ -996,8 +991,8 @@ def _get_src_data(src, mri_resolution=True):
             if s.get("interpolator", None) is None:
                 if mri_resolution:
                     raise RuntimeError(
-                        "MRI interpolator not present in src[%d], "
-                        "cannot use mri_resolution=True" % (si,)
+                        f"MRI interpolator not present in src[{si}], "
+                        "cannot use mri_resolution=True"
                     )
                 interpolator = None
                 break
@@ -1218,7 +1213,7 @@ def _compute_morph_matrix(
     data = np.concatenate(data)
     # this is equivalent to morpher = sparse_block_diag(morpher).tocsr(),
     # but works for xhemi mode
-    morpher = sparse.csr_matrix((data, indices, indptr), shape=shape)
+    morpher = sparse.csr_array((data, indices, indptr), shape=shape)
     logger.info("[done]")
     return morpher
 
@@ -1226,16 +1221,16 @@ def _compute_morph_matrix(
 def _hemi_morph(tris, vertices_to, vertices_from, smooth, maps, warn):
     _validate_type(smooth, (str, None, "int-like"), "smoothing steps")
     if len(vertices_from) == 0:
-        return sparse.csr_matrix((len(vertices_to), 0))
+        return sparse.csr_array((len(vertices_to), 0))
     e = mesh_edges(tris)
     e.data[e.data == 2] = 1
     n_vertices = e.shape[0]
-    e += sparse.eye(n_vertices, format="csr")
+    e += _eye_array(n_vertices, format="csr")
     if isinstance(smooth, str):
         _check_option("smooth", smooth, ("nearest",), extra=" when used as a string.")
         mm = _surf_nearest(vertices_from, e).tocsr()
     elif smooth == 0:
-        mm = sparse.csc_matrix(
+        mm = sparse.csc_array(
             (
                 np.ones(len(vertices_from)),  # data, indices, indptr
                 vertices_from,
@@ -1253,7 +1248,7 @@ def _hemi_morph(tris, vertices_to, vertices_from, smooth, maps, warn):
         logger.info(f"    {n_iter} smooth iterations done.")
     assert mm.shape == (n_vertices, len(vertices_from))
     if maps is not None:
-        mm = maps[vertices_to] * mm
+        mm = maps[vertices_to] @ mm
     else:  # to == from
         mm = mm[vertices_to]
     assert mm.shape == (len(vertices_to), len(vertices_from))
@@ -1340,6 +1335,15 @@ def _surf_nearest(vertices, adj_mat):
     # Vertices can be out of order, so sort them to start ...
     order = np.argsort(vertices)
     vertices = vertices[order]
+    # work around https://github.com/scipy/scipy/issues/20904
+    adj_mat = sparse.csr_array(
+        (
+            adj_mat.data,
+            adj_mat.indices.astype(np.int32),
+            adj_mat.indptr.astype(np.int32),
+        ),
+        shape=adj_mat.shape,
+    )
     _, _, sources = sparse.csgraph.dijkstra(
         adj_mat, False, indices=vertices, min_only=True, return_predecessors=True
     )
@@ -1348,7 +1352,7 @@ def _surf_nearest(vertices, adj_mat):
     col = order[col]
     row = np.arange(len(col))
     data = np.ones(len(col))
-    mat = sparse.coo_matrix((data, (row, col)))
+    mat = sparse.coo_array((data, (row, col)))
     assert mat.shape == (adj_mat.shape[0], len(vertices)), mat.shape
     return mat
 
@@ -1366,12 +1370,12 @@ def _csr_row_norm(data, row_norm):
 def _surf_upsampling_mat(idx_from, e, smooth):
     """Upsample data on a subject's surface given mesh edges."""
     # we're in CSR format and it's to==from
-    assert isinstance(e, sparse.csr_matrix)
+    assert isinstance(e, sparse.csr_array)
     n_tot = e.shape[0]
     assert e.shape == (n_tot, n_tot)
     # our output matrix starts out as a smaller matrix, and will gradually
     # increase in size
-    data = sparse.eye(len(idx_from), format="csr")
+    data = _eye_array(len(idx_from), format="csr")
     _validate_type(smooth, ("int-like", str, None), "smoothing steps")
     if smooth is not None:  # number of steps
         smooth = _ensure_int(smooth, "smoothing steps")
@@ -1391,17 +1395,17 @@ def _surf_upsampling_mat(idx_from, e, smooth):
             data = data[idx]
         # smoothing multiplication
         use_e = e[:, idx] if len(idx) < n_tot else e
-        data = use_e * data
+        data = use_e @ data
         del use_e
         # compute row sums + output indices
         if recompute_idx_sum:
             if len(idx) == n_tot:
-                row_sum = np.asarray(e.sum(-1))[:, 0]
+                row_sum = np.asarray(e.sum(-1))
                 idx = np.arange(n_tot)
                 recompute_idx_sum = False
             else:
                 mult[idx] = 1
-                row_sum = e * mult
+                row_sum = e @ mult
                 idx = np.where(row_sum)[0]
         # do row normalization
         _csr_row_norm(data, row_sum)
@@ -1418,7 +1422,7 @@ def _sparse_argmax_nnz_row(csr_mat):
     n_rows = csr_mat.shape[0]
     idx = np.empty(n_rows, dtype=np.int64)
     for k in range(n_rows):
-        row = csr_mat[k].tocoo()
+        row = csr_mat[[k]].tocoo()
         idx[k] = row.col[np.argmax(row.data)]
     return idx
 
@@ -1513,7 +1517,7 @@ def _apply_morph_data(morph, stc_from):
         stc_from_vertices = stc_from.vertices[vol_src_offset:]
         vertices_from = morph._vol_vertices_from
         for ii, (v1, v2) in enumerate(zip(vertices_from, stc_from_vertices)):
-            _check_vertices_match(v1, v2, "volume[%d]" % (ii,))
+            _check_vertices_match(v1, v2, f"volume[{ii}]")
         from_sl = slice(from_surf_stop, from_vol_stop)
         assert not from_used[from_sl].any()
         from_used[from_sl] = True
@@ -1548,7 +1552,7 @@ def _apply_morph_data(morph, stc_from):
         to_sl = slice(0, to_surf_stop)
         assert not to_used[to_sl].any()
         to_used[to_sl] = True
-        data[to_sl] = morph.morph_mat * data_from[from_sl]
+        data[to_sl] = morph.morph_mat @ data_from[from_sl]
     assert to_used.all()
     assert from_used.all()
     data.shape = (data.shape[0],) + stc_from.data.shape[1:]
