@@ -1,5 +1,4 @@
-# Authors: Adonay Nunes <adonay.s.nunes@gmail.com>
-#          Luke Bloy <luke.bloy@gmail.com>
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -541,9 +540,7 @@ def annotate_break(
         )
 
     if not annotations:
-        raise ValueError(
-            "Could not find (or generate) any annotations in " "your data."
-        )
+        raise ValueError("Could not find (or generate) any annotations in your data.")
 
     # Only keep annotations of interest and extract annotated time periods
     # Ignore case
