@@ -1,5 +1,4 @@
-# Author: Mark Wronkiewicz <wronk@uw.edu>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -455,7 +454,7 @@ def test_multipolar_bases():
     sss_data = loadmat(bases_fname)
     exp = dict(int_order=int_order, ext_order=ext_order)
     for origin in ((0, 0, 0.04), (0, 0.02, 0.02)):
-        o_str = "".join("%d" % (1000 * n) for n in origin)
+        o_str = "".join(f"{int(1000 * n)}" for n in origin)
         exp.update(origin=origin)
         S_tot = _sss_basis_basic(exp, coils, method="alternative")
         # Test our real<->complex conversion functions
@@ -669,7 +668,7 @@ def test_spatiotemporal():
     kwargs = dict(origin=mf_head_origin, regularize=None, bad_condition="ignore")
     for st_duration, tol in zip(st_durations, tols):
         # Load tSSS data depending on st_duration and get data
-        tSSS_fname = sss_path / ("test_move_anon_st%0ds_raw_sss.fif" % st_duration)
+        tSSS_fname = sss_path / f"test_move_anon_st{int(st_duration)}s_raw_sss.fif"
         tsss_bench = read_crop(tSSS_fname)
         # Because Elekta's tSSS sometimes(!) lumps the tail window of data
         # onto the previous buffer if it's shorter than st_duration, we have to
@@ -881,15 +880,15 @@ def test_cross_talk(tmp_path):
         maxwell_filter(raw, cross_talk=raw_fname)
     mf_ctc = sss_ctc.info["proc_history"][0]["max_info"]["sss_ctc"]
     del mf_ctc["block_id"]  # we don't write this
-    assert isinstance(py_ctc["decoupler"], sparse.csc_matrix)
-    assert isinstance(mf_ctc["decoupler"], sparse.csc_matrix)
+    assert isinstance(py_ctc["decoupler"], sparse.csc_array)
+    assert isinstance(mf_ctc["decoupler"], sparse.csc_array)
     assert_array_equal(py_ctc["decoupler"].toarray(), mf_ctc["decoupler"].toarray())
     # I/O roundtrip
     fname = tmp_path / "test_sss_raw.fif"
     sss_ctc.save(fname)
     sss_ctc_read = read_raw_fif(fname)
     mf_ctc_read = sss_ctc_read.info["proc_history"][0]["max_info"]["sss_ctc"]
-    assert isinstance(mf_ctc_read["decoupler"], sparse.csc_matrix)
+    assert isinstance(mf_ctc_read["decoupler"], sparse.csc_array)
     assert_array_equal(
         mf_ctc_read["decoupler"].toarray(), mf_ctc["decoupler"].toarray()
     )
@@ -1820,8 +1819,9 @@ def test_prepare_emptyroom_bads(bads):
 @pytest.mark.parametrize("set_annot_when", ("before", "after"))
 @pytest.mark.parametrize("raw_meas_date", ("orig", None))
 @pytest.mark.parametrize("raw_er_meas_date", ("orig", None))
+@pytest.mark.parametrize("equal_sfreq", (False, True))
 def test_prepare_emptyroom_annot_first_samp(
-    set_annot_when, raw_meas_date, raw_er_meas_date
+    set_annot_when, raw_meas_date, raw_er_meas_date, equal_sfreq
 ):
     """Test prepare_emptyroom."""
     raw = read_raw_fif(raw_fname, allow_maxshield="yes", verbose=False)
@@ -1861,12 +1861,15 @@ def test_prepare_emptyroom_annot_first_samp(
         assert set_annot_when == "after"
         meas_date = "from_raw"
         want_date = raw.info["meas_date"]
+    if not equal_sfreq:
+        with raw_er.info._unlock():
+            raw_er.info["sfreq"] -= 100
     raw_er_prepared = maxwell_filter_prepare_emptyroom(
         raw_er=raw_er, raw=raw, meas_date=meas_date, emit_warning=True
     )
     assert raw_er.first_samp == raw_er_first_samp_orig
     assert raw_er_prepared.info["meas_date"] == want_date
-    assert raw_er_prepared.first_samp == raw.first_samp
+    assert raw_er_prepared.first_time == raw.first_time
 
     # Ensure (movement) annotations carry over regardless of whether they're
     # set before or after preparation
@@ -1878,7 +1881,8 @@ def test_prepare_emptyroom_annot_first_samp(
     prop_bad = np.isnan(raw.get_data([0], reject_by_annotation="nan")).mean()
     assert 0.3 < prop_bad < 0.4
     assert len(raw_er_prepared.annotations) == want_annot
-    prop_bad_er = np.isnan(
-        raw_er_prepared.get_data([0], reject_by_annotation="nan")
-    ).mean()
-    assert_allclose(prop_bad, prop_bad_er)
+    if equal_sfreq:
+        prop_bad_er = np.isnan(
+            raw_er_prepared.get_data([0], reject_by_annotation="nan")
+        ).mean()
+        assert_allclose(prop_bad, prop_bad_er)
