@@ -1,6 +1,6 @@
 """Some utility functions for rank estimation."""
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#
+
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -294,7 +294,7 @@ def _get_rank_sss(
         or "in_order" not in proc_info[0]["max_info"]["sss_info"]
     ):
         raise ValueError(
-            "Could not find Maxfilter information in " 'info["proc_history"]. %s' % msg
+            f'Could not find Maxfilter information in info["proc_history"]. {msg}'
         )
     proc_info = proc_info[0]
     max_info = proc_info["max_info"]
@@ -340,7 +340,7 @@ def compute_rank(
 
     This function will normalize the rows of the data (typically
     channels or vertices) such that non-zero singular values
-    should be close to one.
+    should be close to one. It operates on :term:`data channels` only.
 
     Parameters
     ----------
@@ -413,7 +413,10 @@ def _compute_rank(
         info = info.copy()
         info["bads"] = []
         inst = pick_channels_cov(
-            inst, set(inst["names"]) & set(info["ch_names"]), exclude=[], ordered=False
+            inst,
+            set(inst["names"]) & set(info["ch_names"]),
+            exclude=info["bads"] + inst["bads"],
+            ordered=False,
         )
         if info["ch_names"] != inst["names"]:
             info = pick_info(
@@ -474,7 +477,7 @@ def _compute_rank(
                 logger.info(
                     f"    {ch_type_}: rank {this_rank} after "
                     f"{n_proj} projector{_pl(n_proj)} applied to "
-                    "{n_chan} channel{_pl(n_chan)}"
+                    f"{n_chan} channel{_pl(n_chan)}"
                 )
             else:
                 logger.info(f"    {ch_type_}: rank {this_rank} from info")
