@@ -1,6 +1,4 @@
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Eric Larson <larson.eric.d@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -570,9 +568,7 @@ def test_setup_source_space_spacing(tmp_path, spacing, monkeypatch):
     monkeypatch.setenv("SUBJECTS_DIR", str(tmp_path))
     monkeypatch.setenv("SUBJECT", "sample")
     run_subprocess(["mne_setup_source_space"] + args)
-    src = read_source_spaces(
-        tmp_path / "sample" / "bem" / ("sample-%d-src.fif" % spacing)
-    )
+    src = read_source_spaces(tmp_path / "sample" / "bem" / f"sample-{spacing}-src.fif")
     # No need to pass subjects_dir here because we've setenv'ed it
     src_new = setup_source_space("sample", spacing=spacing, add_dist=False)
     _compare_source_spaces(src, src_new, mode="approx", nearest=True)
@@ -1062,7 +1058,7 @@ data_path = mne.datasets.sample.data_path()
 src = mne.setup_source_space('sample', fname=None, spacing='oct5')
 hemis = ['lh', 'rh']
 fnames = [
-    str(data_path) + '/subjects/sample/surf/%s.decimated' % h for h in hemis]
+    str(data_path) + f'/subjects/sample/surf/{h}.decimated' for h in hemis]
 
 vs = list()
 for s, fname in zip(src, fnames):
@@ -1076,7 +1072,7 @@ for s, fname in zip(src, fnames):
 
 # we need to move sphere surfaces
 spheres = [
-    str(data_path) + '/subjects/sample/surf/%s.sphere' % h for h in hemis]
+    str(data_path) + f'/subjects/sample/surf/{h}.sphere' for h in hemis]
 for s in spheres:
     os.rename(s, s + '.bak')
 try:
