@@ -1,9 +1,4 @@
-# Authors: Tal Linzen <linzen@nyu.edu>
-#          Teon Brooks <teon.brooks@gmail.com>
-#          Denis A. Engemann <denis.engemann@gmail.com>
-#          Jona Sassenhagen <jona.sassenhagen@gmail.com>
-#          Marijn van Vliet <w.m.vanvliet@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -60,7 +55,7 @@ def linear_regression(inst, design_matrix, names=None):
         ``(n_channels, n_timepoints)``.
     """
     if names is None:
-        names = ["x%i" % i for i in range(design_matrix.shape[1])]
+        names = [f"x{i}" for i in range(design_matrix.shape[1])]
 
     if isinstance(inst, BaseEpochs):
         picks = pick_types(
@@ -75,7 +70,7 @@ def linear_regression(inst, design_matrix, names=None):
             exclude=["bads"],
         )
         if [inst.ch_names[p] for p in picks] != inst.ch_names:
-            warn("Fitting linear model to non-data or bad channels. " "Check picking")
+            warn("Fitting linear model to non-data or bad channels. Check picking")
         msg = "Fitting linear model to epochs"
         data = inst.get_data(copy=False)
         out = EvokedArray(np.zeros(data.shape[1:]), inst.info, inst.tmin)
@@ -88,7 +83,7 @@ def linear_regression(inst, design_matrix, names=None):
         out = inst[0]
         data = np.array([i.data for i in inst])
     else:
-        raise ValueError("Input must be epochs or iterable of source " "estimates")
+        raise ValueError("Input must be epochs or iterable of source estimates")
     logger.info(msg + f", ({np.prod(data.shape[1:])} targets, {len(names)} regressors)")
     lm_params = _fit_lm(data, design_matrix, names)
     lm = namedtuple("lm", "beta stderr t_val p_val mlog10_p_val")
@@ -116,7 +111,7 @@ def _fit_lm(data, design_matrix, names):
 
     if n_samples != n_rows:
         raise ValueError(
-            "Number of rows in design matrix must be equal " "to number of observations"
+            "Number of rows in design matrix must be equal to number of observations"
         )
     if n_predictors != len(names):
         raise ValueError(
