@@ -1,6 +1,4 @@
-# Authors: Jaakko Leppakangas <jaeilepp@student.jyu.fi>
-#          Robert Luke <mail@robertluke.net>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -194,7 +192,7 @@ def test_crop(tmp_path):
     events = mne.find_events(raw)
     onset = events[events[:, 2] == 1, 0] / raw.info["sfreq"]
     duration = np.full_like(onset, 0.5)
-    description = ["bad %d" % k for k in range(len(onset))]
+    description = [f"bad {k}" for k in range(len(onset))]
     annot = mne.Annotations(
         onset, duration, description, orig_time=raw.info["meas_date"]
     )
@@ -791,7 +789,7 @@ def test_events_from_annot_in_raw_objects():
     assert isinstance(event_id, dict)
     assert len(event_id) > 0
     for kind in ("BAD", "EDGE"):
-        assert "%s boundary" % kind in raw_concat.annotations.description
+        assert f"{kind} boundary" in raw_concat.annotations.description
         for key in event_id.keys():
             assert kind not in key
 
@@ -1035,7 +1033,7 @@ def test_io_annotation(dummy_annotation_file, tmp_path, fmt, ch_names):
 def test_broken_csv(tmp_path):
     """Test broken .csv that does not use timestamps."""
     pytest.importorskip("pandas")
-    content = "onset,duration,description\n" "1.,1.0,AA\n" "3.,2.425,BB"
+    content = "onset,duration,description\n1.,1.0,AA\n3.,2.425,BB"
     fname = tmp_path / "annotations_broken.csv"
     with open(fname, "w") as f:
         f.write(content)
@@ -1049,7 +1047,7 @@ def test_broken_csv(tmp_path):
 @pytest.fixture(scope="function", params=("ch_names",))
 def dummy_annotation_txt_file(tmp_path_factory, ch_names):
     """Create txt file for testing."""
-    content = "3.14, 42, AA \n" "6.28, 48, BB"
+    content = "3.14, 42, AA \n6.28, 48, BB"
     if ch_names:
         content = content.splitlines()
         content[0] = content[0].strip() + ","
@@ -1132,7 +1130,7 @@ def test_read_annotation_txt_header(tmp_path):
 
 def test_read_annotation_txt_one_segment(tmp_path):
     """Test empty TXT input/output."""
-    content = "# MNE-Annotations\n" "# onset, duration, description\n" "3.14, 42, AA"
+    content = "# MNE-Annotations\n# onset, duration, description\n3.14, 42, AA"
     fname = tmp_path / "one-annotations.txt"
     with open(fname, "w") as f:
         f.write(content)
@@ -1142,7 +1140,7 @@ def test_read_annotation_txt_one_segment(tmp_path):
 
 def test_read_annotation_txt_empty(tmp_path):
     """Test empty TXT input/output."""
-    content = "# MNE-Annotations\n" "# onset, duration, description\n"
+    content = "# MNE-Annotations\n# onset, duration, description\n"
     fname = tmp_path / "empty-annotations.txt"
     with open(fname, "w") as f:
         f.write(content)
@@ -1171,7 +1169,7 @@ def test_annotations_simple_iteration():
             elements.values(), EXPECTED_ELEMENTS_TYPE, expected_values
         ):
             assert np.isscalar(elem)
-            assert type(elem) == expected_type
+            assert isinstance(elem, expected_type)
             assert elem == expected_value
 
 
