@@ -1,13 +1,13 @@
-# Author: Tommy Clausner <Tommy.Clausner@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
+
 from inspect import signature
 
 import numpy as np
 import pytest
 from numpy.testing import assert_allclose, assert_array_equal, assert_array_less
-from scipy.sparse import csr_matrix
+from scipy.sparse import csr_array
 from scipy.sparse import eye as speye
 from scipy.spatial.distance import cdist
 
@@ -55,7 +55,6 @@ fname_fmorph = data_path / "MEG" / "sample" / "fsaverage_audvis_trunc-meg"
 fname_smorph = sample_dir / "sample_audvis_trunc-meg"
 fname_t1 = subjects_dir / "sample" / "mri" / "T1.mgz"
 fname_vol = subjects_dir / "sample" / "bem" / "sample-volume-7mm-src.fif"
-fname_brain = subjects_dir / "sample" / "mri" / "brain.mgz"
 fname_aseg = subjects_dir / "sample" / "mri" / "aseg.mgz"
 fname_fs_vol = subjects_dir / "fsaverage" / "bem" / "fsaverage-vol7-nointerp-src.fif.gz"
 fname_aseg_fs = subjects_dir / "fsaverage" / "mri" / "aseg.mgz"
@@ -672,7 +671,7 @@ def test_volume_source_morph_round_trip(
         morph_to_from.compute_vol_morph_mat(verbose=True)
         morph_to_from.save(fname, overwrite=True)
         morph_to_from = read_source_morph(fname)
-        assert isinstance(morph_to_from.vol_morph_mat, csr_matrix), "csr"
+        assert isinstance(morph_to_from.vol_morph_mat, csr_array), "csr"
         # equivalence (plus automatic calling)
         assert morph_from_to.vol_morph_mat is None
         monkeypatch.setattr(mne.morph, "_VOL_MAT_CHECK_RATIO", 0.0)
@@ -681,7 +680,7 @@ def test_volume_source_morph_round_trip(
                 stc_from_rt_lin = morph_to_from.apply(
                     morph_from_to.apply(stc_from, verbose="debug")
                 )
-        assert isinstance(morph_from_to.vol_morph_mat, csr_matrix), "csr"
+        assert isinstance(morph_from_to.vol_morph_mat, csr_array), "csr"
         log = log.getvalue()
         assert "sparse volume morph matrix" in log
         assert_allclose(stc_from_rt.data, stc_from_rt_lin.data)
