@@ -1,6 +1,6 @@
 """Testing functions."""
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#
+
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -10,7 +10,6 @@ import sys
 import tempfile
 import traceback
 from functools import wraps
-from io import StringIO
 from shutil import rmtree
 from unittest import SkipTest
 
@@ -141,23 +140,6 @@ class ArgvSetter:
         sys.stderr = self.orig_stderr
 
 
-class SilenceStdout:
-    """Silence stdout."""
-
-    def __init__(self, close=True):
-        self.close = close
-
-    def __enter__(self):  # noqa: D105
-        self.stdout = sys.stdout
-        sys.stdout = StringIO()
-        return sys.stdout
-
-    def __exit__(self, *args):  # noqa: D105
-        if self.close:
-            sys.stdout.close()
-        sys.stdout = self.stdout
-
-
 def has_mne_c():
     """Check for MNE-C."""
     return "MNE_ROOT" in os.environ
@@ -192,7 +174,7 @@ def assert_and_remove_boundary_annot(annotations, n=1):
     if isinstance(annotations, BaseRaw):  # allow either input
         annotations = annotations.annotations
     for key in ("EDGE", "BAD"):
-        idx = np.where(annotations.description == "%s boundary" % key)[0]
+        idx = np.where(annotations.description == f"{key} boundary")[0]
         assert len(idx) == n
         annotations.delete(idx)
 
@@ -242,7 +224,7 @@ def _check_snr(actual, desired, picks, min_tol, med_tol, msg, kind="MEG"):
     # min tol
     snr = snrs.min()
     bad_count = (snrs < min_tol).sum()
-    msg = " (%s)" % msg if msg != "" else msg
+    msg = f" ({msg})" if msg != "" else msg
     assert bad_count == 0, (
         f"SNR (worst {snr:0.2f}) < {min_tol:0.2f} "
         f"for {bad_count}/{len(picks)} channels{msg}"
