@@ -1,7 +1,6 @@
 """Some utility functions."""
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Clemens Brunner <clemens.brunner@gmail.com>
-#
+
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -12,7 +11,7 @@ import os
 import shutil
 import sys
 from contextlib import contextmanager
-from datetime import datetime, timedelta, timezone
+from datetime import date, datetime, timedelta, timezone
 from io import BytesIO, StringIO
 from math import ceil, sqrt
 from pathlib import Path
@@ -64,19 +63,6 @@ def array_split_idx(ary, indices_or_sections, axis=0, n_per_split=1):
     return zip(idx_split, ary_split)
 
 
-def create_chunks(sequence, size):
-    """Generate chunks from a sequence.
-
-    Parameters
-    ----------
-    sequence : iterable
-        Any iterable object
-    size : int
-        The chunksize to be returned
-    """
-    return (sequence[p : p + size] for p in range(0, len(sequence), size))
-
-
 def sum_squared(X):
     """Compute norm of an array.
 
@@ -178,11 +164,11 @@ def _reg_pinv(x, reg=0, rank="full", rcond=1e-15):
     # Warn the user if both all parameters were kept at their defaults and the
     # matrix is rank deficient.
     if (rank_after < n).any() and reg == 0 and rank == "full" and rcond == 1e-15:
-        warn("Covariance matrix is rank-deficient and no regularization is " "done.")
+        warn("Covariance matrix is rank-deficient and no regularization is done.")
     elif isinstance(rank, int) and rank > n:
         raise ValueError(
-            "Invalid value for the rank parameter (%d) given "
-            "the shape of the input matrix (%d x %d)." % (rank, x.shape[0], x.shape[1])
+            f"Invalid value for the rank parameter ({rank}) given "
+            f"the shape of the input matrix ({x.shape[0]} x {x.shape[1]})."
         )
 
     # Pick the requested number of singular values
@@ -243,7 +229,7 @@ def _reject_data_segments(data, reject, flat, decim, info, tstep):
             data_clean[:, this_start:this_stop] = data_buffer
             this_start += data_buffer.shape[1]
         else:
-            logger.info("Artifact detected in [%d, %d]" % (first, last))
+            logger.info(f"Artifact detected in [{first}, {last}]")
             drop_inds.append((first, last))
     data = data_clean[:, :this_stop]
     if not data.any():
@@ -373,7 +359,7 @@ def _apply_scaling_cov(data, picks_list, scalings):
             scales[idx] = scalings[ch_t]
     elif isinstance(scalings, np.ndarray):
         if len(scalings) != len(data):
-            raise ValueError("Scaling factors and data are of incompatible " "shape")
+            raise ValueError("Scaling factors and data are of incompatible shape")
         scales = scalings
     elif scalings is None:
         pass
@@ -404,9 +390,7 @@ def _check_scaling_inputs(data, picks_list, scalings):
     elif scalings is None:
         pass
     else:
-        raise NotImplementedError(
-            "No way! That's not a rescaling " "option: %s" % scalings
-        )
+        raise NotImplementedError(f"Not a valid rescaling option: {scalings}")
     return scalings_
 
 
@@ -435,17 +419,6 @@ def hashfunc(fname, block_size=1048576, hash_type="md5"):  # 2 ** 20
     return hasher.hexdigest()
 
 
-def _replace_md5(fname):
-    """Replace a file based on MD5sum."""
-    # adapted from sphinx-gallery
-    assert fname.endswith(".new")
-    fname_old = fname[:-4]
-    if os.path.isfile(fname_old) and hashfunc(fname) == hashfunc(fname_old):
-        os.remove(fname)
-    else:
-        shutil.move(fname, fname_old)
-
-
 def create_slices(start, stop, step=None, length=1):
     """Generate slices of time indexes.
 
@@ -620,7 +593,7 @@ def grand_average(all_inst, interpolate_bads=True, drop_bads=True):
     # change the grand_average.nave to the number of Evokeds
     grand_average.nave = len(all_inst)
     # change comment field
-    grand_average.comment = "Grand average (n = %d)" % grand_average.nave
+    grand_average.comment = f"Grand average (n = {grand_average.nave})"
     return grand_average
 
 
@@ -675,7 +648,7 @@ def object_hash(x, h=None):
         object_hash(_dt_to_stamp(x))
     elif sparse.issparse(x):
         h.update(str(type(x)).encode("utf-8"))
-        if not isinstance(x, (sparse.csr_matrix, sparse.csc_matrix)):
+        if not isinstance(x, (sparse.csr_array, sparse.csc_array)):
             raise RuntimeError(f"Unsupported sparse type {type(x)}")
         h.update(x.data.tobytes())
         h.update(x.indices.tobytes())
@@ -733,7 +706,9 @@ def object_size(x, memo=None):
         size = sys.getsizeof(x) + sum(object_size(xx, memo) for xx in x)
     elif isinstance(x, datetime):
         size = object_size(_dt_to_stamp(x), memo)
-    elif sparse.isspmatrix_csc(x) or sparse.isspmatrix_csr(x):
+    elif isinstance(x, date):
+        size = 24  # 3 8-byte integers
+    elif _is_sparse_cs(x):
         size = sum(sys.getsizeof(xx) for xx in [x, x.data, x.indices, x.indptr])
     else:
         raise RuntimeError(f"unsupported type: {type(x)} ({x})")
@@ -741,6 +716,12 @@ def object_size(x, memo=None):
     return size
 
 
+def _is_sparse_cs(x):
+    return isinstance(
+        x, (sparse.csr_matrix, sparse.csc_matrix, sparse.csr_array, sparse.csc_array)
+    )
+
+
 def _sort_keys(x):
     """Sort and return keys of dict."""
     keys = list(x.keys())  # note: not thread-safe
@@ -783,7 +764,7 @@ def object_diff(a, b, pre="", *, allclose=False):
     """
     pd = _check_pandas_installed(strict=False)
     out = ""
-    if type(a) != type(b):
+    if type(a) is not type(b):
         # Deal with NamedInt and NamedFloat
         for sub in (int, float):
             if isinstance(a, sub) and isinstance(b, sub):
@@ -798,20 +779,20 @@ def object_diff(a, b, pre="", *, allclose=False):
         k2s = _sort_keys(b)
         m1 = set(k2s) - set(k1s)
         if len(m1):
-            out += pre + " left missing keys %s\n" % (m1)
+            out += pre + f" left missing keys {m1}\n"
         for key in k1s:
             if key not in k2s:
-                out += pre + " right missing key %s\n" % key
+                out += pre + f" right missing key {key}\n"
             else:
                 out += object_diff(
-                    a[key], b[key], pre=(pre + "[%s]" % repr(key)), allclose=allclose
+                    a[key], b[key], pre=(pre + f"[{repr(key)}]"), allclose=allclose
                 )
     elif isinstance(a, (list, tuple)):
         if len(a) != len(b):
             out += pre + f" length mismatch ({len(a)}, {len(b)})\n"
         else:
             for ii, (xx1, xx2) in enumerate(zip(a, b)):
-                out += object_diff(xx1, xx2, pre + "[%s]" % ii, allclose=allclose)
+                out += object_diff(xx1, xx2, pre + f"[{ii}]", allclose=allclose)
     elif isinstance(a, float):
         if not _array_equal_nan(a, b, allclose):
             out += pre + f" value mismatch ({a}, {b})\n"
@@ -820,27 +801,27 @@ def object_diff(a, b, pre="", *, allclose=False):
             out += pre + f" value mismatch ({a}, {b})\n"
     elif a is None:
         if b is not None:
-            out += pre + " left is None, right is not (%s)\n" % (b)
+            out += pre + f" left is None, right is not ({b})\n"
     elif isinstance(a, np.ndarray):
         if not _array_equal_nan(a, b, allclose):
             out += pre + " array mismatch\n"
     elif isinstance(a, (StringIO, BytesIO)):
         if a.getvalue() != b.getvalue():
             out += pre + " StringIO mismatch\n"
-    elif isinstance(a, datetime):
+    elif isinstance(a, (datetime, date)):
         if (a - b).total_seconds() != 0:
-            out += pre + " datetime mismatch\n"
-    elif sparse.isspmatrix(a):
+            out += pre + f" {a.__class__.__name__} mismatch\n"
+    elif sparse.issparse(a):
         # sparsity and sparse type of b vs a already checked above by type()
         if b.shape != a.shape:
             out += pre + (
-                " sparse matrix a and b shape mismatch" f"({a.shape} vs {b.shape})"
+                f" sparse matrix a and b shape mismatch ({a.shape} vs {b.shape})"
             )
         else:
             c = a - b
             c.eliminate_zeros()
             if c.nnz > 0:
-                out += pre + (" sparse matrix a and b differ on %s " "elements" % c.nnz)
+                out += pre + (f" sparse matrix a and b differ on {c.nnz} elements")
     elif pd and isinstance(a, pd.DataFrame):
         try:
             pd.testing.assert_frame_equal(a, b)
@@ -887,7 +868,7 @@ class _PCA:
         if n_components == "mle":
             if n_samples < n_features:
                 raise ValueError(
-                    "n_components='mle' is only supported " "if n_samples >= n_features"
+                    "n_components='mle' is only supported if n_samples >= n_features"
                 )
         elif not 0 <= n_components <= min(n_samples, n_features):
             raise ValueError(
@@ -959,8 +940,8 @@ def _mask_to_onsets_offsets(mask):
     return onsets, offsets
 
 
-def _julian_to_dt(jd):
-    """Convert Julian integer to a datetime object.
+def _julian_to_date(jd):
+    """Convert Julian integer to a date object.
 
     Parameters
     ----------
@@ -982,15 +963,15 @@ def _julian_to_dt(jd):
     datetime_t0 = datetime(1970, 1, 1, 12, 0, 0, 0, tzinfo=timezone.utc)
 
     dt = timedelta(days=(jd - jd_t0))
-    return datetime_t0 + dt
+    return (datetime_t0 + dt).date()
 
 
-def _dt_to_julian(jd_date):
+def _date_to_julian(jd_date):
     """Convert datetime object to a Julian integer.
 
     Parameters
     ----------
-    jd_date : datetime
+    jd_date : date
 
     Returns
     -------
@@ -1005,54 +986,11 @@ def _dt_to_julian(jd_date):
     # https://aa.usno.navy.mil/data/docs/JulianDate.php
     # Thursday, A.D. 1970 Jan 1 12:00:00.0  2440588.000000
     jd_t0 = 2440588
-    datetime_t0 = datetime(1970, 1, 1, 12, 0, 0, 0, tzinfo=timezone.utc)
-
-    dt = jd_date - datetime_t0
+    date_t0 = date(1970, 1, 1)
+    dt = jd_date - date_t0
     return jd_t0 + dt.days
 
 
-def _cal_to_julian(year, month, day):
-    """Convert calendar date (year, month, day) to a Julian integer.
-
-    Parameters
-    ----------
-    year : int
-        Year as an integer.
-    month : int
-        Month as an integer.
-    day : int
-        Day as an integer.
-
-    Returns
-    -------
-    jd: int
-        Julian date.
-    """
-    return int(_dt_to_julian(datetime(year, month, day, 12, 0, 0, tzinfo=timezone.utc)))
-
-
-def _julian_to_cal(jd):
-    """Convert calendar date (year, month, day) to a Julian integer.
-
-    Parameters
-    ----------
-    jd: int, float
-        Julian date.
-
-    Returns
-    -------
-    year : int
-        Year as an integer.
-    month : int
-        Month as an integer.
-    day : int
-        Day as an integer.
-
-    """
-    tmp_date = _julian_to_dt(jd)
-    return tmp_date.year, tmp_date.month, tmp_date.day
-
-
 def _check_dt(dt):
     if (
         not isinstance(dt, datetime)
@@ -1167,3 +1105,14 @@ def _array_repr(x):
     """Produce compact info about float ndarray x."""
     assert isinstance(x, np.ndarray), type(x)
     return f"shape : {x.shape}, range : [{np.nanmin(x):+0.2g}, {np.nanmax(x):+0.2g}]"
+
+
+def _replace_md5(fname):
+    """Replace a file based on MD5sum."""
+    # adapted from sphinx-gallery
+    assert fname.endswith(".new")
+    fname_old = fname[:-4]
+    if os.path.isfile(fname_old) and hashfunc(fname) == hashfunc(fname_old):
+        os.remove(fname)
+    else:
+        shutil.move(fname, fname_old)
