@@ -1,10 +1,5 @@
 #
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Eric Larson <larson.eric.d@gmail.com>
-#          Joan Massich <mailsik@gmail.com>
-#          Guillaume Favelier <guillaume.favelier@gmail.com>
-#          Oleh Kozynets <ok7mailbox@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -1042,8 +1037,8 @@ def test_brain_traces(renderer_interactive_pyvistaqt, hemi, src, tmp_path, brain
             subject=brain._subject,
             subjects_dir=brain._subjects_dir,
         )
-        label = "{}:{} MNI: {}".format(
-            hemi_prefix, str(vertex_id).ljust(6), ", ".join("%5.1f" % m for m in mni)
+        label = f"{hemi_prefix}:{str(vertex_id).ljust(6)} MNI: " + ", ".join(
+            f"{m:5.1f}" for m in mni
         )
 
         assert line.get_label() == label
@@ -1080,7 +1075,7 @@ something
         src_dir=str(tmp_path),
         compress_images=[],
         image_srcset=[],
-        matplotlib_animations=False,
+        matplotlib_animations=(False, None),
     )
     scraper = _BrainScraper()
     rst = scraper(block, block_vars, gallery_conf)
@@ -1105,10 +1100,7 @@ something
 def test_brain_scraper(renderer_interactive_pyvistaqt, brain_gc, tmp_path):
     """Test a simple scraping example."""
     pytest.importorskip("sphinx_gallery")
-    from qtpy import API_NAME
 
-    if API_NAME.lower() == "pyside6":
-        pytest.skip("Error in event loop on PySidie6")
     stc = read_source_estimate(fname_stc, subject="sample")
     size = (600, 400)
     brain = stc.plot(
@@ -1128,7 +1120,7 @@ def test_brain_scraper(renderer_interactive_pyvistaqt, brain_gc, tmp_path):
         src_dir=str(tmp_path),
         compress_images=[],
         image_srcset=[],
-        matplotlib_animations=False,
+        matplotlib_animations=(False, None),
     )
     scraper = _BrainScraper()
     rst = scraper(block, block_vars, gallery_conf)
@@ -1141,8 +1133,7 @@ def test_brain_scraper(renderer_interactive_pyvistaqt, brain_gc, tmp_path):
     img = image.imread(fname)
     w = img.shape[1]
     w0 = size[0]
-    # With matplotlib 3.6 on Linux+conda we get a width of 624,
-    # similar tweak in test_brain_init above
+    # On Linux+conda we get a width of 624, similar tweak in test_brain_init above
     assert np.isclose(w, w0, atol=30) or np.isclose(
         w, w0 * 2, atol=30
     ), f"w ∉ {{{w0}, {2 * w0}}}"  # HiDPI
