@@ -1,10 +1,6 @@
 """Core visualization operations."""
 
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Eric Larson <larson.eric.d@gmail.com>
-#          Joan Massich <mailsik@gmail.com>
-#          Guillaume Favelier <guillaume.favelier@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -44,7 +40,7 @@ def _reload_backend(backend_name):
     backend = importlib.import_module(
         name=_backend_name_map[backend_name], package="mne.viz.backends"
     )
-    logger.info("Using %s 3d backend.\n" % backend_name)
+    logger.info(f"Using {backend_name} 3d backend.")
 
 
 def _get_backend():
@@ -405,7 +401,6 @@ class _TimeInteraction:
         self._times = times
         self._init_time = current_time_func()
         self._init_playback_speed = init_playback_speed
-        self._playback_speed_range = playback_speed_range
 
         if not hasattr(self, "_dock"):
             self._dock_initialize()
