@@ -1,10 +1,6 @@
 """Functions to plot ICA specific data (besides topographies)."""
 
-# Authors: Denis Engemann <denis.engemann@gmail.com>
-#          Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Teon Brooks <teon.brooks@gmail.com>
-#          Daniel McCloy <dan.mccloy@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -339,7 +335,7 @@ def _plot_ica_properties(
         _set_scale(spec_ax, "log")
 
     # epoch variance
-    var_ax_title = "Dropped segments: %.2f %%" % var_percent
+    var_ax_title = f"Dropped segments: {var_percent:.2f} %"
     set_title_and_labels(var_ax, var_ax_title, kind, "Variance (AU)")
 
     hist_ax.set_ylabel("")
@@ -379,10 +375,10 @@ def _plot_ica_properties(
     return fig
 
 
-def _get_psd_label_and_std(this_psd, dB, ica, num_std):
+def _get_psd_label_and_std(this_psd, dB, ica, num_std, *, estimate):
     """Handle setting up PSD for one component, for plot_ica_properties."""
     psd_ylabel = _convert_psds(
-        this_psd, dB, estimate="auto", scaling=1.0, unit="AU", first_dim="epoch"
+        this_psd, dB, estimate=estimate, scaling=1.0, unit="AU", first_dim="epoch"
     )
     psds_mean = this_psd.mean(axis=0)
     diffs = this_psd - psds_mean
@@ -417,6 +413,7 @@ def plot_ica_properties(
     reject="auto",
     reject_by_annotation=True,
     *,
+    estimate="power",
     verbose=None,
 ):
     """Display component properties.
@@ -487,6 +484,9 @@ def plot_ica_properties(
     %(reject_by_annotation_raw)s
 
         .. versionadded:: 0.21.0
+    %(estimate_plot_psd)s
+
+        .. versionadded:: 1.8.0
     %(verbose)s
 
     Returns
@@ -514,6 +514,7 @@ def plot_ica_properties(
         reject=reject,
         reject_by_annotation=reject_by_annotation,
         verbose=verbose,
+        estimate=estimate,
         precomputed_data=None,
     )
 
@@ -535,6 +536,7 @@ def _fast_plot_ica_properties(
     precomputed_data=None,
     reject_by_annotation=True,
     *,
+    estimate="power",
     verbose=None,
 ):
     """Display component properties."""
@@ -557,7 +559,7 @@ def _fast_plot_ica_properties(
         fig, axes = _create_properties_layout(figsize=figsize)
     else:
         if len(picks) > 1:
-            raise ValueError("Only a single pick can be drawn " "to a set of axes.")
+            raise ValueError("Only a single pick can be drawn to a set of axes.")
         from .utils import _validate_if_list_of_axes
 
         _validate_if_list_of_axes(axes, obligatory_len=5)
@@ -626,7 +628,11 @@ def _fast_plot_ica_properties(
     for idx, pick in enumerate(picks):
         # calculate component-specific spectrum stuff
         psd_ylabel, psds_mean, spectrum_std = _get_psd_label_and_std(
-            psds[:, idx, :].copy(), dB, ica, num_std
+            psds[:, idx, :].copy(),
+            dB,
+            ica,
+            num_std,
+            estimate=estimate,
         )
 
         # if more than one component, spawn additional figures and axes
@@ -1000,14 +1006,12 @@ def plot_ica_scores(
         labels = (None,) * n_scores
 
     if len(labels) != n_scores:
-        raise ValueError(
-            "Need as many labels (%i) as scores (%i)" % (len(labels), n_scores)
-        )
+        raise ValueError(f"Need as many labels ({len(labels)}) as scores ({n_scores})")
 
     for label, this_scores, ax in zip(labels, scores, axes):
         if len(my_range) != len(this_scores):
             raise ValueError(
-                "The length of `scores` must equal the " "number of ICA components."
+                "The length of `scores` must equal the number of ICA components."
             )
         ax.bar(my_range, this_scores, color="gray", edgecolor="k")
         for excl in exclude:
@@ -1025,7 +1029,7 @@ def plot_ica_scores(
                 label = ", ".join([split[0], split[2]])
             elif "/" in label:
                 label = ", ".join(label.split("/"))
-            ax.set_title("(%s)" % label)
+            ax.set_title(f"({label})")
         ax.set_xlabel("ICA components")
         ax.set_xlim(-0.6, len(this_scores) - 0.4)
     fig.canvas.draw()
@@ -1100,7 +1104,7 @@ def plot_ica_overlay(
     if exclude is None:
         exclude = ica.exclude
     if not isinstance(exclude, (np.ndarray, list)):
-        raise TypeError("exclude must be of type list. Got %s" % type(exclude))
+        raise TypeError(f"exclude must be of type list. Got {type(exclude)}")
     if isinstance(inst, BaseRaw):
         start = 0.0 if start is None else start
         stop = 3.0 if stop is None else stop
