@@ -1,16 +1,9 @@
 """Utility functions for plotting M/EEG data."""
 
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Denis Engemann <denis.engemann@gmail.com>
-#          Martin Luessi <mluessi@nmr.mgh.harvard.edu>
-#          Eric Larson <larson.eric.d@gmail.com>
-#          Mainak Jas <mainak@neuro.hut.fi>
-#          Stefan Appelhoff <stefan.appelhoff@mailbox.org>
-#          Clemens Brunner <clemens.brunner@gmail.com>
-#          Daniel McCloy <dan@mccloy.info>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
+
 import difflib
 import math
 import os
@@ -22,7 +15,6 @@ from collections import defaultdict
 from contextlib import contextmanager
 from datetime import datetime
 from functools import partial
-from inspect import signature
 
 import numpy as np
 from decorator import decorator
@@ -59,7 +51,6 @@ from ..utils import (
     _pl,
     _to_rgb,
     _validate_type,
-    check_version,
     fill_doc,
     get_config,
     logger,
@@ -394,9 +385,7 @@ def _get_channel_plotting_order(order, ch_types, picks=None):
             if order_type == pick_type
         ]
     elif not isinstance(order, (np.ndarray, list, tuple)):
-        raise ValueError(
-            "order should be array-like; got " f'"{order}" ({type(order)}).'
-        )
+        raise ValueError(f'order should be array-like; got "{order}" ({type(order)}).')
     if picks is not None:
         order = [ch for ch in order if ch in picks]
     return np.asarray(order, int)
@@ -684,12 +673,6 @@ def _show_help_fig(col1, col2, fig_help, ax, show):
             pass
 
 
-def _show_help(col1, col2, width, height):
-    fig_help = figure_nobar(figsize=(width, height), dpi=80)
-    ax = fig_help.add_subplot(111)
-    _show_help_fig(col1, col2, fig_help, ax, show=True)
-
-
 def _key_press(event):
     """Handle key press in dialog."""
     import matplotlib.pyplot as plt
@@ -798,10 +781,6 @@ class ClickableImage:
         return lt
 
 
-def _old_mpl_events():
-    return not check_version("matplotlib", "3.6")
-
-
 def _fake_click(fig, ax, point, xform="ax", button=1, kind="press", key=None):
     """Fake a click at a relative point within axes."""
     from matplotlib import backend_bases
@@ -813,40 +792,28 @@ def _fake_click(fig, ax, point, xform="ax", button=1, kind="press", key=None):
     else:
         assert xform == "pix"
         x, y = point
-    # This works on 3.6+, but not on <= 3.5.1 (lasso events not propagated)
-    if _old_mpl_events():
-        if kind == "press":
-            fig.canvas.button_press_event(x=x, y=y, button=button)
-        elif kind == "release":
-            fig.canvas.button_release_event(x=x, y=y, button=button)
-        elif kind == "motion":
-            fig.canvas.motion_notify_event(x=x, y=y)
+    if kind in ("press", "release"):
+        kind = f"button_{kind}_event"
     else:
-        if kind in ("press", "release"):
-            kind = f"button_{kind}_event"
-        else:
-            assert kind == "motion"
-            kind = "motion_notify_event"
-            button = None
-        logger.debug(f"Faking {kind} @ ({x}, {y}) with button={button} and key={key}")
-        fig.canvas.callbacks.process(
-            kind,
-            backend_bases.MouseEvent(
-                name=kind, canvas=fig.canvas, x=x, y=y, button=button, key=key
-            ),
-        )
+        assert kind == "motion"
+        kind = "motion_notify_event"
+        button = None
+    logger.debug(f"Faking {kind} @ ({x}, {y}) with button={button} and key={key}")
+    fig.canvas.callbacks.process(
+        kind,
+        backend_bases.MouseEvent(
+            name=kind, canvas=fig.canvas, x=x, y=y, button=button, key=key
+        ),
+    )
 
 
 def _fake_keypress(fig, key):
-    if _old_mpl_events():
-        fig.canvas.key_press_event(key)
-    else:
-        from matplotlib import backend_bases
+    from matplotlib import backend_bases
 
-        fig.canvas.callbacks.process(
-            "key_press_event",
-            backend_bases.KeyEvent(name="key_press_event", canvas=fig.canvas, key=key),
-        )
+    fig.canvas.callbacks.process(
+        "key_press_event",
+        backend_bases.KeyEvent(name="key_press_event", canvas=fig.canvas, key=key),
+    )
 
 
 def _fake_scroll(fig, x, y, step):
@@ -949,7 +916,7 @@ def _process_times(inst, use_times, n_peaks=None, few=False):
     use_times = np.array(use_times, float)
 
     if use_times.ndim != 1:
-        raise ValueError("times must be 1D, got %d dimensions" % use_times.ndim)
+        raise ValueError(f"times must be 1D, got {use_times.ndim} dimensions")
 
     if len(use_times) > 25:
         warn("More than 25 topomaps plots requested. This might take a while.")
@@ -1167,7 +1134,7 @@ def plot_sensors(
                 if pick in value:
                     colors[pick_idx] = color_vals[ind]
                     break
-    title = "Sensor positions (%s)" % ch_type if title is None else title
+    title = f"Sensor positions ({ch_type})" if title is None else title
     fig = _plot_sensors_2d(
         pos,
         info,
@@ -1558,7 +1525,7 @@ class DraggableColorbar:
             self.index = 0
         cmap = self.cycle[self.index]
         self.cbar.mappable.set_cmap(cmap)
-        _draw_without_rendering(self.cbar)
+        self.cbar.ax.figure.draw_without_rendering()
         self.mappable.set_cmap(cmap)
         self._publish()
 
@@ -1622,20 +1589,11 @@ class DraggableColorbar:
 
         self.cbar.set_ticks(AutoLocator())
         self.cbar.update_ticks()
-        _draw_without_rendering(self.cbar)
+        self.cbar.ax.figure.draw_without_rendering()
         self.mappable.set_norm(self.cbar.norm)
         self.cbar.ax.figure.canvas.draw()
 
 
-def _draw_without_rendering(cbar):
-    # draw_all deprecated in Matplotlib 3.6
-    try:
-        meth = cbar.ax.figure.draw_without_rendering
-    except AttributeError:
-        meth = cbar.draw_all
-    return meth()
-
-
 class SelectFromCollection:
     """Select channels from a matplotlib collection using ``LassoSelector``.
 
@@ -1699,8 +1657,9 @@ class SelectFromCollection:
         self.ec[:, -1] = self.alpha_other
         self.lw = np.full(self.Npts, self.linewidth_other)
 
-        line_kw = _prop_kw("line", dict(color="red", linewidth=0.5))
-        self.lasso = LassoSelector(ax, onselect=self.on_select, **line_kw)
+        self.lasso = LassoSelector(
+            ax, onselect=self.on_select, props=dict(color="red", linewidth=0.5)
+        )
         self.selection = list()
         self.callbacks = list()
 
@@ -2164,7 +2123,7 @@ def _check_time_unit(time_unit, times):
     elif time_unit == "ms":
         times = 1e3 * times
     else:
-        raise ValueError("time_unit must be 's' or 'ms', got %r" % time_unit)
+        raise ValueError(f"time_unit must be 's' or 'ms', got {time_unit!r}")
     return time_unit, times
 
 
@@ -2426,9 +2385,7 @@ def _convert_psds(
             msg += "\nThese channels might be dead."
         warn(msg, UserWarning)
 
-    if estimate == "auto":
-        estimate = "power" if dB else "amplitude"
-
+    _check_option("estimate", estimate, ("power", "amplitude"))
     if estimate == "amplitude":
         np.sqrt(psds, out=psds)
         psds *= scaling
@@ -2772,15 +2729,6 @@ def _generate_default_filename(ext=".png"):
     return "MNE" + dt_string + ext
 
 
-def _prop_kw(kind, val):
-    # Can be removed in when we depend on matplotlib 3.5+
-    # https://github.com/matplotlib/matplotlib/pull/20585
-    from matplotlib.widgets import SpanSelector
-
-    pre = "" if "props" in signature(SpanSelector).parameters else kind
-    return {pre + "props": val}
-
-
 def _handle_precompute(precompute):
     _validate_type(precompute, (bool, str, None), "precompute")
     if precompute is None:
@@ -2839,12 +2787,7 @@ def _get_cmap(colormap, lut=None):
     elif not isinstance(colormap, colors.Colormap):
         colormap = get_cmap(colormap)
     if lut is not None:
-        # triage method for MPL 3.6 ('resampled') or older ('_resample')
-        if hasattr(colormap, "resampled"):
-            resampled = colormap.resampled
-        else:
-            resampled = colormap._resample
-        colormap = resampled(lut)
+        colormap = colormap.resampled(lut)
     return colormap
 
 
@@ -2863,5 +2806,7 @@ def _get_plot_ch_type(inst, ch_type, allow_ref_meg=False):
                 ch_type = type_
                 break
         else:
-            raise RuntimeError("No plottable channel types found")
+            raise RuntimeError(
+                f"No plottable channel types found. Allowed types are: {allowed_types}"
+            )
     return ch_type
